package PAR::StrippedPARL::Dynamic;
use 5.008001;
use strict;
use warnings;
our $VERSION = '0.958';

use base 'PAR::StrippedPARL::Base';

our $Data_Pos = tell DATA;

=head1 NAME

PAR::StrippedPARL::Dynamic - Data package containing a dynamic PARL

=head1 SYNOPSIS

  # For details, see PAR::StrippedPARL::Base.
  PAR::StrippedPARL::Dynamic->write_parl($file) or die "Some error...";

=head1 DESCRIPTION

This class is internal to PAR. Do not use it outside of PAR.

This class is basically just a container for a dynamic binary PAR loader
which doesn't include the PAR code like the F<parl> or F<parl.exe>
you are used to. If you're really curious, I'll tell you it is
just a copy of the F<myldr/par> (or F<myldr/par.exe>) file.

The data is appended during the C<make> phase of the PAR build process,
but only if applicable: If you perl is static, you won't get the dynamic
loader.

If the binary data isn't appended during the build process, the class
methods will return the empty list.

=head1 CLASS METHODS

Inherits the methods from L<PAR::StrippedPARL::Base>.

=cut

sub _data_pos {
    my $class = shift;
    return $Data_Pos;
}

=head1 AUTHORS

Steffen Mueller E<lt>smueller@cpan.orgE<gt>,
Audrey Tang E<lt>cpan@audreyt.orgE<gt>

=head1 COPYRIGHT AND LICENSE

Copyright 2006-2009 by Steffen Mueller E<lt>smueller@cpan.orgE<gt>.

This program is free software; you can redistribute it and/or 
modify it under the same terms as Perl itself.

See L<http://www.perl.com/perl/misc/Artistic.html>

=cut


__DATA__
M?T5,1@$!`0D```````````(``P`!````-)H$"#0````,Q0```````#0`(``(
M`"@`'0`<``8````T````-(`$"#2`!`@``0````$```4````$`````P```#0!
M```T@00(-($$"`T````-````!`````$````!``````````"`!`@`@`0(S&4`
M`,QE```%`````!````$```#,90``S/4$",SU!`@87@``I&(```8`````$```
M`@```.!E``#@]00(X/4$"/@```#X````!@````0````$````1`$``$2!!`A$
M@00(1````$0````$````!````%#E=&2@8```H.`$"*#@!`C,````S`````0`
M```$````4>5T9```````````````````````````!@````0````O;&EB+VQD
M+G-O+C$`````!````!`````!````1TY5``,````(```````````````$````
M%`````,```!'3E4`3D1M4+@BLY`YBC%7:!+=Q2P^#R-A````9```````````
M`````````!@``````````````#4`````````"````!L````:`````````#X`
M```Z````4@`````````1````1````$4```!`````5@```$(````'````.P``
M````````````-@```%@````Y``````````````!)````4````$P````X````
M`````&,```!(````$@```#$`````````#``````````I`````````$,```!'
M``````````````!<````,P```&`````7``````````````!/````(0```#<`
M```]```````````````+`````````"8``````````````#\`````````+@``
M`"`````<````)````%0```!?``````````````!9````2P```"@````G````
M/````"T````R`````````%H```````````````````!;````2@`````````J
M````40````4````B````4P````8`````````````````````````````````
M``````````````````````````````D`````````70``````````````````
M``````````````````H`````````8@``````````````%`````````!7````
M````````````````#P```!X````0`````````%X````3`````````!8```!5
M````00```$T`````````)0`````````````````````````L````%0```"\`
M```````````````````````````````````=``````````````!&````(P``
M````````````!```````````````````````````````-````!\````-````
M````````````````&0````````!A`````````"L``````````````#`````"
M````````````````````3@``````````````````````````````#@``````
M```!`````P``````````````$0```$`````(````"``````<$`0E0`2".`%`
M`:*&`:A````"2R@$*3BB,D>*!`P(0````$$```!%````2@```$L```!2````
M5````%8```!9````6P````````!=````80````````!B``````````````![
M\$IK;L7?'^K3[P[.WD<M:W^:?"[%F[8@_^0.?$&.Q;B-\0[59-1\V7%8'.)'
MQ@&L2^/`\MO3';KCDGS"Y3\L^J%L8+,!BV]J"4/6A_F<@6:OS&;%N9Q`0D75
M[,2)!9`Y\HL<#!3BGLG5LG':S>.>,V+;[0PZEPM6I)N6IMVC:UGH[>Q_J9R;
M"HH05Z/@^TD`````````````````````!P,`````````````$@```*4"````
M`````````!(````V`P`````````````2````#@,`````````````$@```/(!
M`````````````!(```#Y`0`````````````2````B0(`````````````$@``
M`%<"`````````````!(```!I`@`````````````2````K`(`````````````
M$@```)T``````````````!(````H`P`````````````2````>0``````````
M````$@```/,``````````````!(```">`@`````````````2````<0(`````
M````````$@```%P!`````````````!(```!'`@`````````````2````%@,`
M````````````$@```!P!`````````````!(```"K```````````````2````
MI@$`````````````$@```$,!`````````````!(```!/`@`````````````2
M````,`(`````````````$@```),!`````````````!(````0`@``````````
M```2````V@(`````````````$@```,<"`````````````!(````J`0``````
M```````2````8`(`````````````$@````H"`````````````!(````1````
M```````````@````T@(`````````````$@```$(``````````````!(```"S
M`@`````````````2````+P,`````````````$@```,H``````````````!(`
M``"K`P`````````````2````B```````````````$@```.4!````````````
M`!(```!1`0`````````````2````^0(`````````````$@```#0`````````
M`````!(````@`P`````````````2````^```````````````$@```/T`````
M`````````!(```#``@`````````````2````B`$`````````````$@```-<`
M`````````````!(``````P`````````````2````N@(`````````````$@``
M`&H!`````````````!(```""`@`````````````2````CP(`````````````
M$@```"```````````````"`````Z`0`````````````2````EP(`````````
M````$@```.H!`````````````!(```!1```````````````2````GP$`````
M````````$@```$("`````````````!(```#D`@`````````````2````>`$`
M`/"4!`@`````$@```+0#``"@VP0(>````!(`#@""`P``7-T$"``````2``\`
MV0,``/#+!`B%"P``$@`.`$,#``!0F`0(X@$``!(`#@"(`P``\,4$"`,````2
M``X`+@0```#&!`BU`0``$@`.`%L$```@W`0(20```!(`#@`H!```^),$"```
M```2``P`=P0``(#7!`@2!```$@`.`&<#``#D4P4(`````!``\?_``P``P,<$
M""\````2``X`\P,``'S=!`@$````$0`0`+$!```-5`4($P```!$`&@!S`P``
M<%@%"``````0`/'_)@0``%#%!`@T````$@`.`#L$````RP0(\````!(`#@!-
M!```@,H$"$(````2``X`Y@,```#X!`@`````$``9`&@```"PEP0(`````!(`
M``#-`P``\,<$".(````2``X`2`,```!4!0@$````$0`:`&`#``#D4P4(````
M`!``\?])`P```%0%"`0````A`!H`\@(``"!4!0@$````$0`:`'@#``#`W`0(
M!0```!(`#@`)`0``\)8$"``````2`````@0``-#<!`A:````$@`.`.P#```T
MF@0(`````!(`#@#H`P```/@$"``````@`!D`Z`````A4!0@$````$0`:`$H#
M````5`4(!````"$`&@`2!```>-T$"`0````1`!``F0,``-#*!`@D````$@`.
M`+T````,5`4(`0```!$`&@`9!```X,@$")\!```2``X``&QI8G!E<FPN<V\N
M-2XQ-`!?7V=M;VY?<W1A<G1?7P!?2G9?4F5G:7-T97)#;&%S<V5S`%!E<FQ?
M<WES7W1E<FT`4&5R;%]S>7-?:6YI=#,`4&5R;%]S879E7V1E<W1R=6-T;W)?
M>`!097)L7V%T9F]R:U]L;V-K`'!E<FQ?8V]N<W1R=6-T`%!E<FQ?8W)O86M?
M;F]C;VYT97AT`%!E<FQ?879?<VAI9G0`4&5R;%]S=E\R<'9?9FQA9W,`4$Q?
M9&]?=6YD=6UP`%!E<FQ?;F5W4U9P=@!097)L7VYE=UA37V9L86=S`%!,7W1H
M<E]K97D`<&5R;%]F<F5E`%!E<FQ?;6=?<V5T`%!E<FQ?871F;W)K7W5N;&]C
M:P!097)L7W-V7W-E='!V`%!E<FQ?9W9?9F5T8VAP=@!P97)L7W)U;@!097)L
M7V1O=6YW:6YD`%!E<FQ?;F5W6%,`<&5R;%]D97-T<G5C=`!097)L7V%V7V9E
M=&-H`&)O;W1?1'EN84QO861E<@!P97)L7W!A<G-E`%!E<FQ?<V%F97-Y<VUA
M;&QO8P!P97)L7V%L;&]C`%!,7VUE;6]R>5]W<F%P`&QI8F1L+G-O+C(`;&EB
M;2YS;RXQ`&QI8G!T:')E860N<V\N,`!R96%D`&QS965K-C0`;W!E;C8T`%]?
M97)R;F]?;&]C871I;VX`8VQO<V4`<'1H<F5A9%]G971S<&5C:69I8P!L:6)C
M+G-O+C`N,0!?7W)E9VES=&5R7V%T9F]R:P!E>&ET`'-P<FEN=&8`<W1R;F-M
M<`!?7W-T<F1U<`!C;&]S961I<@!S=')N8W!Y`%]?<W1A8VM?8VAK7V9A:6P`
M=6YL:6YK`&UK9&ER`')E86QL;V,`9V5T<&ED`'-T<G1O:P!S=')L96X`;65M
M<V5T`'-T<G-T<@!R;61I<@!M96UC<'D`7U]L>'-T870V-`!O<&5N9&ER`%]?
M>'-T870V-`!?7V-T>7!E7V)?;&]C`'-T9&5R<@!G971U:60`97AE8W9P`'-T
M<F-H<@!F<')I;G1F`')E861D:7(V-`!M96UM;W9E`&%C8V5S<P!S=')C;7``
M7U]L:6)C7W-T87)T7VUA:6X`7U]E;G9I<F]N`&QI8F-R>7!T+G-O+C$`7V5D
M871A`%]?8G-S7W-T87)T`%]E;F0`7U]L:6)C7V-S=5]F:6YI`'!A<E]C=7)R
M96YT7V5X96,`9V5T7W5S97)N86UE7V9R;VU?9V5T<'=U:60`<&%R7V-L96%N
M=7``<&%R7V)A<V5N86UE`'!A<E]D:7)N86UE`'!A<E]M:W1M<&1I<@!?7V1A
M=&%?<W1A<G0`7TE/7W-T9&EN7W5S960`7U]L:6)C7V-S=5]I;FET`%]F<%]H
M=P!P87)?:6YI=%]E;G8`>'-?:6YI=`!P87)?9FEN9'!R;V<`<&%R7W-E='5P
M7VQI8G!A=&@`<&%R7V5N=E]C;&5A;@!84U]);G1E<FYA;'-?4$%27T-,14%2
M4U1!0TL`6%-?26YT97)N86QS7U!!4E]"3T]4`$=,24)#7S(N,P!'3$E"0U\R
M+C,N,@!'3$E"0U\R+C0``````@`"``(``@`#``,``@`"``(``@````(`````
M``(`!`````(``@````````````(`!0````,``@`"`````@`#`````@````(`
M`@````(````#`````@````(``@````(```````(``@````(``@```````@`#
M`````@`"``(````!``$``0`!``$``0`!``$``0`!``$``0````$``0`!``$`
M`0````$``@`!``(``@`!`````0`!``$````"``$``0````$````!``$`U0$`
M`!`````@````$VEI#0```P"-!`````````$``P`D`@``$`````````!R&6D)
M```%`)<$```0````%&EI#0``!`"C!```$````!-I:0T```(`C00```````#8
M]@0(!B$```!4!0@%50``"%0%"`5>```,5`4(!6(```U4!0@%30``(%0%"`58
M``#L]@0(!P$``/#V!`@'`@``]/8$"`<#``#X]@0(!P0``/SV!`@'!0```/<$
M"`<&```$]P0(!P<```CW!`@'"```#/<$"`<)```0]P0(!PH``!3W!`@'"P``
M&/<$"`=````<]P0(!PP``"#W!`@'#0``)/<$"`<.```H]P0(!P\``"SW!`@'
M$```,/<$"`<1```T]P0(!Q(``#CW!`@'$P``//<$"`<4``!`]P0(!Q4``$3W
M!`@'%@``2/<$"`<7``!,]P0(!Q@``%#W!`@'&0``5/<$"`<:``!8]P0(!QL`
M`%SW!`@''```8/<$"`<=``!D]P0(!QX``&CW!`@''P``;/<$"`<@``!P]P0(
M!R$``'3W!`@'(@``>/<$"`<C``!\]P0(!R0``(#W!`@')0``A/<$"`<F``"(
M]P0(!R<``(SW!`@'*```D/<$"`<I``"4]P0(!RH``)CW!`@'6@``G/<$"`<K
M``"@]P0(!RP``*3W!`@'+0``J/<$"`<N``"L]P0(!R\``+#W!`@',```M/<$
M"`<Q``"X]P0(!S(``+SW!`@',P``P/<$"`<T``#$]P0(!S4``,CW!`@'4P``
MS/<$"`<V``#0]P0(!S<``-3W!`@'.0``V/<$"`<Z``#<]P0(!SL``.#W!`@'
M/```Y/<$"`<]``#H]P0(!SX``.SW!`@'/P``58GE4X/L!.@`````6X'#W&(`
M`(N3^/___X72=`7H-@(``.BA!@``Z`Q)``!86\G#``````````#_->3V!`C_
M)>CV!`@`````_R7L]@0(:`````#IX/____\E\/8$"&@(````Z=#_____)?3V
M!`AH$````.G`_____R7X]@0(:!@```#IL/____\E_/8$"&@@````Z:#_____
M)0#W!`AH*````.F0_____R4$]P0(:#````#I@/____\E"/<$"&@X````Z7#_
M____)0SW!`AH0````.E@_____R40]P0(:$@```#I4/____\E%/<$"&A0````
MZ4#_____)1CW!`AH6````.DP_____R4<]P0(:&````#I(/____\E(/<$"&AH
M````Z1#_____)23W!`AH<````.D`_____R4H]P0(:'@```#I\/[___\E+/<$
M"&B`````Z>#^____)3#W!`AHB````.G0_O___R4T]P0(:)````#IP/[___\E
M./<$"&B8````Z;#^____)3SW!`AHH````.F@_O___R5`]P0(:*@```#ID/[_
M__\E1/<$"&BP````Z8#^____)4CW!`AHN````.EP_O___R5,]P0(:,````#I
M8/[___\E4/<$"&C(````Z5#^____)53W!`AHT````.E`_O___R58]P0(:-@`
M``#I,/[___\E7/<$"&C@````Z2#^____)6#W!`AHZ````.D0_O___R5D]P0(
M:/````#I`/[___\E:/<$"&CX````Z?#]____)6SW!`AH``$``.G@_?___R5P
M]P0(:`@!``#IT/W___\E=/<$"&@0`0``Z<#]____)7CW!`AH&`$``.FP_?__
M_R5\]P0(:"`!``#IH/W___\E@/<$"&@H`0``Z9#]____)83W!`AH,`$``.F`
M_?___R6(]P0(:#@!``#I</W___\EC/<$"&A``0``Z6#]____)9#W!`AH2`$`
M`.E0_?___R64]P0(:%`!``#I0/W___\EF/<$"&A8`0``Z3#]____)9SW!`AH
M8`$``.D@_?___R6@]P0(:&@!``#I$/W___\EI/<$"&AP`0``Z0#]____):CW
M!`AH>`$``.GP_/___R6L]P0(:(`!``#IX/S___\EL/<$"&B(`0``Z=#\____
M);3W!`AHD`$``.G`_/___R6X]P0(:)@!``#IL/S___\EO/<$"&B@`0``Z:#\
M____)<#W!`AHJ`$``.F0_/___R7$]P0(:+`!``#I@/S___\ER/<$"&BX`0``
MZ7#\____)<SW!`AHP`$``.E@_/___R70]P0(:,@!``#I4/S___\EU/<$"&C0
M`0``Z4#\____)=CW!`AHV`$``.DP_/___R7<]P0(:.`!``#I(/S___\EX/<$
M"&CH`0``Z1#\____)>3W!`AH\`$``.D`_/___R7H]P0(:/@!``#I\/O___\E
M[/<$"&@``@``Z>#[__]5B>564X/D\(/L,(U%$(E$)`B-10R)1"0$C44(B00D
MZ/S]___'1"0(\)8$",=$)`3PE@0(QP0DL)<$".C@0P``@#T,5`4(`'4NZ`+]
M__^%P*-L6`4(#X1[`0``B00DZ%W\__^A"%0%"(D$).@P_?__QH"8`@```*$(
M5`4(,=N)!"3H&OW__X"(VP(```*A"%0%"(D$).@&_?__BU4(@\(%@(C;`@``
M`8E4)"B)7"0LWVPD*-@%E.`$"-T%F.`$"-G)VNG?X)X/A_8```#!X@*)%"3H
MN?S__XMU#(M=",<%9%@%"`0```"+%H/[`:-@6`4(QT`$2M\$"(D0QT`(0/@$
M",=`#$W?!`A^%+H!````D(L,EHE,D`R#P@$YVG7R@\,#QP28`````(E$)`RA
M;%@%"(E<)`C'1"00`````,=$)`20Q00(B00DZ,/]__^%P(G#=#:A;%@%"(D$
M).B@^___N`[>!`CHUB4``(7`="RA;%@%"(D$).A5^___Z$#]__^-9?B)V%M>
M7<.A;%@%"(D$).CZ_?__B</KN:%H6`4(A<!T"HD$).BE00``Z\&XP]T$".B)
M)0``A<"C:%@%"'2NZ^''1"0$#50%",<$)(/=!`CHFOS__\<$)`$```#H_OW_
M_Y"0,>U>B>&#Y/!05%)HP-P$"&C0W`0(459H4)@$".@+^O__])"0D)"0D)"0
MD)!5B>53@^P$@#TD5`4(`'4_H2A4!0B[V/4$"('KU/4$",'[`H/K`3G8<QZ-
MM@````"#P`&C*%0%"/\4A=3U!`BA*%0%"#G8<NC&!214!0@!@\0$6UW#C70F
M`(V\)P````!5B>6#[!BAW/4$"(7`=!*X`````(7`=`G'!"3<]00(_]#)PY"0
MD)"0D)"0D)"0D)!5B<57@\4X5E,QVX'LY`(``(E$)%2-=@"+=)T`BWR=!,=$
MW&0`````QT3<;`````")\,'@"(GZB<&)\,'@&('A``#_``G!B?`/K-`(B?HE
M`/\```G!B?`/K-`8B?XE_P```#'_"<&)\,'@"(GZB4S<8(G!B?#!X!B!X0``
M_P`)P8GP#ZS0"(GZ)0#_```)P8GP#ZS0&"7_````"<&)3-QH@\,"@_L0#X5L
M____C8PDR````(V<),@"``"-M@````"+4=B+0=R+<9B+>9PS$3-!!#-1J#-!
MK,=!'``````QUC''B?")^@^LT!^)1"0HB?`!P`M$)"C!ZA^)5"0LB4$8@\$(
M.=EUN8M,)%2+="14BVPD5(L1BUX(BTD$BWT0B50D((M4)%2)7"08BUPD5(MV
M#(E,)"2+;12+0AB+2R")="0<BW0D((E\)!"+?"0DB40D"(M2'(G(BULD`T0D
M8(D,)(EL)!2+;"00!9EY@EH/K/X;BWPD((GQBW0D%(E4)`R)7"0$P><%"?D!
MR(M,)!@C="0<(VPD&/?1(TPD"(ET)"B+5"0<BUPD((G.BTPD&`GN`?`Q_XG&
MBT0D&,'A'L=$)$0`````QT0D/``````/K-`"BU0D)(G%BT0D"`G-BTPD(`-$
M)&B);"1`!9EY@EKWT2-,)!`AZXML)"0)RXGQB5PD*(G[]]4C;"04`T0D*`^L
MV1N)3"0HB?'!X06)3"0PBTPD*`M,)#");"0LQT0D+``````!R(M,)"")1"0H
MBT0D(,'A'@^LT`*)^HG%BT0D$`G-B?$#1"1P]]&)ZXEL)#@%F7F"6B'S(TPD
M0`G9B4PD,,=$)#0`````BUPD+(M,)"@#1"0PQT0D-`````"+?"0TQT0D3```
M```/K-D;B4PD,(M,)"C'1"1$`````,'A!8E,)$B+3"0P"TPD2`'(BTPD*(E$
M)#")\`^LT`*+5"0LP>8>B<.+1"1`"?/WT0-$)'B)7"1(BUPD*`69>8):(>DC
M7"1(B<X)WHM<)#`!\(MT)#`/K/X;BWPD,(GQP><%"?D!R(M,)"@Q_XG&BT0D
M*,'A'@^LT`*)Q8M$)#@)S8M,)#`#A"2`````B6PD0`69>8):]]$C3"1((>L)
MV8G[B4PD*(GQBU0D-`-$)"@/K-D;B4PD*(GQP>$%B4PD.(M,)"@+3"0XQT0D
M+`````#'1"0L``````'(BTPD,(E$)"B+1"0PQT0D-`````#'1"0T`````,'A
M'@^LT`*)^HM\)#2)Q8M$)$@)S8GQ`X0DB````/?1B>N);"0X!9EY@EHA\R-,
M)$#'1"0\`````,=$)$P`````"=F+7"0LB4PD,(M,)"@#1"0P#ZS9&XE,)#"+
M3"0HP>$%B4PD2(M,)#`+3"1(`<B+3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$
M)$`)\_?1`X0DD````(E<)$B+7"0H!9EY@EHAZ2-<)$B)S@G>`?"+="0P#ZS^
M&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$)"C!X1X/K-`"B<4)S8EL)$"+1"0X
MBTPD,`.$))@```"+7"0PBU0D-`69>8):]]$C3"1((>O'1"0L``````G9B?N)
M3"0HB?$#1"0H#ZS9&XE,)"B)\<'A!8E,)#B+3"0H"TPD.,=$)"P`````QT0D
M1``````!R(M,)#")1"0HBT0D,,=$)#P`````QT0D-`````#!X1X/K-`"B?J)
MQ8M$)$@)S8GQ`X0DH````/?1B>N);"0X!9EY@EHA\R-,)$`)V8M<)"R)3"0P
MBTPD*`-$)#`/K-D;B4PD,(M,)"C!X06)3"1(BTPD,`M,)$C'1"0T`````(M\
M)#3'1"1,``````'(BTPD*(E$)#")\`^LT`*+5"0LP>8>B<.+1"1`"?/WT0.$
M)*@```")7"1(BUPD*,=$)$0`````!9EY@EHAZ2-<)$B)SL=$)"P`````"=Z+
M7"0P`?"+="0P#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$)"C!X1X/K-`"
MB<6+1"0X"<V+3"0P`X0DL````(EL)$`%F7F"6O?1(TPD2"'K"=F)^XE,)"B)
M\0-$)"@/K-D;B4PD*(GQP>$%B4PD.(M,)"@+3"0X`<B)1"0HBT0D,(M4)#2+
M3"0PQT0D+`````#'1"0T``````^LT`*)^L'A'HG%BT0D2`G-B?$#A"2X````
M]]&)Z\=$)#0`````BWPD-`69>8):(?,C3"1`B6PD.,=$)#P`````"=F+7"0L
MB4PD,(M,)"@#1"0PQT0D3``````/K-D;B4PD,(M,)"C!X06)3"1(BTPD,`M,
M)$@!R(M,)"B)1"0PB?`/K-`"BU0D+,'F'HG#BT0D0`GS]]$#A"3`````B5PD
M2(M<)"@%F7F"6B'I(UPD2(G."=X!\(MT)#`/K/X;BWPD,(GQP><%"?D!R(M,
M)"@Q_XG&BT0D*,'A'@^LT`*)Q0G-B6PD0(M$)#B+3"0P`X0DR````(M<)#"+
M5"0T!9EY@EKWT2-,)$@AZ\=$)"P`````"=F)^XE,)"B)\0-$)"@/K-D;B4PD
M*(GQP>$%B4PD.(M,)"@+3"0XQT0D+`````#'1"1$``````'(BTPD,(E$)"B+
M1"0PQT0D/`````#'1"0T`````,'A'@^LT`*)^HG%BT0D2`G-B?$#A"30````
M]]&)ZXEL)#@%F7F"6B'S(TPD0`G9BUPD+(E,)#"+3"0H`T0D,`^LV1N)3"0P
MBTPD*,'A!8E,)$B+3"0P"TPD2,=$)#0`````BWPD-,=$)$P``````<B+3"0H
MB40D,(GP#ZS0`HM4)"S!YAZ)PXM$)$`)\_?1`X0DV````(E<)$B+7"0HQT0D
M1``````%F7F"6B'I(UPD2(G.QT0D+``````)WHM<)#`!\(MT)#`/K/X;BWPD
M,(GQP><%"?D!R(M,)"@Q_XG&BT0D*,'A'@^LT`*)Q8M$)#@)S8M,)#`#A"3@
M````B6PD0`69>8):]]$C3"1((>L)V8G[B4PD*(GQ`T0D*`^LV1N)3"0HB?'!
MX06)3"0XBTPD*`M,)#@!R(E$)"B+1"0PBU0D-(M,)##'1"0L`````,=$)#0`
M````#ZS0`HGZP>$>B<6+1"1("<V)\0.$).@```#WT8GKQT0D-`````"+?"0T
M!9EY@EHA\R-,)$");"0XQT0D/``````)V8M<)"R)3"0PBTPD*`-$)##'1"1,
M``````^LV1N)3"0PBTPD*,'A!8E,)$B+3"0P"TPD2`'(BTPD*(E$)#")\`^L
MT`*+5"0LP>8>B<.+1"1`"?/WT0.$)/````")7"1(BUPD*`69>8):(>DC7"1(
MB<X)W@'PBW0D,`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HP>$>#ZS0
M`HG%"<V);"1`BT0D.(M,)#`#A"3X````BUPD,(M4)#0%F7F"6O?1(TPD2"'K
MQT0D+``````)V8G[B4PD*(GQ`T0D*`^LV1N)3"0HB?'!X06)3"0XBTPD*`M,
M)#C'1"0L`````(M<)"S'1"1$``````'(BTPD,(E$)"B+1"0PQT0D/`````#!
MX1X/K-`"B?J)Q8M$)$@)S0.$)``!``");"0X!:'KV6XS;"1`B>DQ\0'(BTPD
M*`^LV1N)3"0PBTPD*,'A!8E,)$B+3"0P"TPD2`'(B40D,(GPBTPD*`^LT`*+
M5"0LP>8>B<.+1"1`"?.+="0X`X0D"`$``,=$)#0`````BWPD-(E<)$@%H>O9
M;C'>,?&+="0P`<C'1"0L`````,=$)$P`````#ZS^&XM\)#")\<=$)$0`````
MQT0D/`````#!YP4)^0'(BTPD*#'_B<:+1"0HB?O!X1X/K-`"BU0D-(G%BT0D
M.`G-BTPD,`.$)!`!``");"1`!:'KV6XS;"1(,>D!R(GQ#ZS9&XM<)"R)3"0H
MB?'!X06)3"0XBTPD*`M,)#@!R(M,)#")1"0HBT0D,,'A'@^LT`*)^HG%BT0D
M2`G-`X0D&`$``(EL)#@%H>O9;C-L)$")Z3'Q`<B+3"0H#ZS9&XE,)#"+3"0H
MQT0D-`````"+?"0TQT0D3`````#'1"1$`````,'A!8E,)$B+3"0P"TPD2`'(
MBTPD*(E$)#")\`^LT`*+5"0LP>8>B<.+1"1`"?.+="0X`X0D(`$``(E<)$C'
M1"0L``````6AZ]EN,=XQ\8MT)#`!R`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_
MB<:+1"0HB?O!X1X/K-`"BU0D-(G%BT0D.`G-BTPD,`.$)"@!``");"1`!:'K
MV6XS;"1(,>D!R(GQ#ZS9&XE,)"B)\<'A!8E,)#B+3"0H"TPD.`'(BTPD,(E$
M)"B+1"0PP>$>#ZS0`HGZB<4)S8EL)#B+1"1(`X0D,`$``(M<)"S'1"0T````
M`(M\)#0%H>O9;C-L)$#'1"0\`````,=$)$P`````B>DQ\0'(BTPD*,=$)$0`
M````#ZS9&XE,)#"+3"0HP>$%B4PD2(M,)#`+3"1(`<B+3"0HB40D,(GP#ZS0
M`HM4)"S!YAZ)PXM$)$`)\XMT)#@#A"0X`0``B5PD2`6AZ]EN,=XQ\8MT)#`!
MR`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HB?O!X1X/K-`"B<6+1"0X
M"<V+3"0P`X0D0`$``(EL)$`%H>O9;C-L)$@QZ0'(B?$/K-D;B4PD*(GQBU0D
M-,'A!8E,)#B+3"0H"TPD.,=$)"P`````BUPD+,=$)#0``````<B+3"0PB40D
M*(M$)##'1"0\`````,=$)$P`````P>$>#ZS0`HGZBWPD-(G%BT0D2`G-`X0D
M2`$``(EL)#@%H>O9;C-L)$")Z3'Q`<B+3"0H#ZS9&XE,)#"+3"0HP>$%B4PD
M2(M,)#`+3"1(`<B+3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$)$`)\XMT)#@#
MA"10`0``B5PD2`6AZ]EN,=XQ\8MT)#`!R`^L_AN+?"0PB?'!YP4)^0'(BTPD
M*#'_B<:+1"0HB?O!X1X/K-`"B<4)S8EL)$"+1"0X`X0D6`$``(M,)#"+5"0T
M!:'KV6XS;"1(QT0D+`````#'1"0T`````#'I`<B)\0^LV1N+7"0LB4PD*(GQ
MP>$%B4PD.(M,)"@+3"0XQT0D1`````#'1"0\``````'(BTPD,(E$)"B+1"0P
MQT0D3`````#!X1X/K-`"B?J+?"0TB<6+1"1("<T#A"1@`0``B6PD.`6AZ]EN
M,VPD0(GI,?$!R(M,)"@/K-D;B4PD,(M,)"C!X06)3"1(BTPD,`M,)$@!R(M,
M)"B)1"0PB?`/K-`"BU0D+,'F'HG#BT0D0`GSBW0D.`.$)&@!``")7"1(!:'K
MV6XQWC'QBW0D,`'(#ZS^&XM\)#")\<'G!0GY`<B+3"0H,?^)QHM$)"B)^\'A
M'@^LT`*)Q0G-B6PD0(M$)#@#A"1P`0``BTPD,(M4)#0%H>O9;C-L)$C'1"0L
M`````,=$)#0`````,>D!R(GQ#ZS9&XM<)"R)3"0HB?'!X06)3"0XBTPD*`M,
M)#C'1"1$`````,=$)#P``````<B+3"0PB40D*(M$)##'1"1,`````,'A'@^L
MT`*)^HM\)#2)Q8M$)$@)S0.$)'@!``");"0X!:'KV6XS;"1`B>DQ\0'(BTPD
M*`^LV1N)3"0PBTPD*,'A!8E,)$B+3"0P"TPD2`'(BTPD*(E$)#")\`^LT`*+
M5"0LP>8>B<.+1"1`"?.+="0X`X0D@`$``(E<)$@%H>O9;C'>,?&+="0P`<@/
MK/X;BWPD,(GQP><%"?D!R(M,)"@Q_XG&BT0D*(G[P>$>#ZS0`HG%"<V);"1`
MBT0D.`.$)(@!``"+3"0PBU0D-`6AZ]EN,VPD2,=$)"P`````QT0D-``````Q
MZ0'(B?$/K-D;BUPD+(E,)"B)\<'A!8E,)#B+3"0H"TPD.,=$)$0`````QT0D
M7``````!R(M,)#")1"0HBT0D,,=$)#P`````P>$>#ZS0`HGZBWPD-(G%BT0D
M2`G-`X0DD`$``(EL)%@%H>O9;C-L)$")Z3'Q`<B+3"0H#ZS9&XE,)#"+3"0H
MP>$%B4PD.(M,)#`+3"0X`<B+3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$)$`)
M\XMT)%@#A"28`0``B5PD.`6AZ]EN,=XQ\8MT)#`!R`^L_AN+?"0PB?'!YP4)
M^0'(BTPD*#'_B<:+1"0HP>$>#ZS0`HG%"<V);"0HBTPD.(M$)%@#A"2@`0``
MBUPD.(M4)#0%W+P;CPGI(TPD,"'KQT0D1``````)V8G[B4PD0(GQ`T0D0`^L
MV1N+7"0HB4PD0(GQP>$%B4PD2(M,)$`+3"1(QT0D1`````#'1"0L``````'(
MBTPD,(E$)$"+1"0PQT0D-`````#'1"0\`````,'A'@^LT`*)^HG%BT0D.`G-
MBTPD*`.$)*@!``");"0P!=R\&X\)Z2'K(?$)V8M<)$2)3"0XBTPD0`-$)#@/
MK-D;B4PD.(M,)$#'1"0\`````(M\)#S'1"1,`````,=$)"P`````P>$%B4PD
M2(M,)#@+3"1(QT0D-``````!R(E$)#B)\`^LT`*+5"1$P>8>B<.+1"0H"?,#
MA"2P`0``B=F)7"1(!=R\&X\)Z2-,)$`AZXG."=Z+7"1(`?"+="0X#ZS^&XM\
M)#B)\<'G!0GY`<B+3"1`,?^)QHM$)$#!X1X/K-`"B<6+1"0P"<V+3"1(`X0D
MN`$``(EL)"@%W+P;CPGI(TPD."'K"=F)^XE,)#")\0-$)#`/K-D;B4PD,(GQ
MP>$%B4PD0(M,)#`+3"1``<B)1"0PBT0D.(M4)#R+3"0XBUPD*,=$)#0`````
M#ZS0`HGZP>$>B<6+1"1("<V+3"0H`X0DP`$``,=$)#P`````QT0D/`````"+
M?"0\!=R\&X\)Z2'K(?$)V8M<)#2)3"0XBTPD,`-$)#B);"1`QT0D1``````/
MK-D;B4PD.(M,)##'1"1,`````,'A!8E,)$B+3"0X"TPD2`'(B40D.(GP#ZS0
M`HM4)#3!YAZ)PXM$)"@)\P.$),@!``")V8E<)$@%W+P;CPGI(TPD,"'KB<X)
MW@'PBW0D.`^L_AN+?"0XB?'!YP4)^0'(BTPD,#'_B<:+1"0PP>$>#ZS0`HG%
M"<V);"0HBT0D0(M,)$@#A"30`0``BUPD2(M4)#P%W+P;CPGI(TPD."'KQT0D
M-``````)V8G[B4PD,(GQ`T0D,`^LV1N+7"0HB4PD,(GQP>$%B4PD0(M,)#`+
M3"1`QT0D-`````#'1"0L``````'(BTPD.(E$)#"+1"0XQT0D1`````#'1"0\
M`````,'A'@^LT`*)^HG%BT0D2`G-BTPD*`.$)-@!``");"1`!=R\&X\)Z2'K
M(?$)V8M<)#2)3"0XBTPD,`-$)#@/K-D;B4PD.(M,)##'1"0\`````(M\)#S'
M1"1,`````,=$)"P`````P>$%B4PD2(M,)#@+3"1(`<B)1"0XB?`/K-`"BU0D
M-,'F'HG#BT0D*`GS`X0DX`$``(G9B5PD2,=$)#0`````!=R\&X\)Z2-,)#`A
MZXG."=Z+7"1(`?"+="0X#ZS^&XM\)#B)\<'G!0GY`<B+3"0P,?^)QHM$)##!
MX1X/K-`"B<6+1"1`"<V+3"1(`X0DZ`$``(EL)"@%W+P;CPGI(TPD."'K"=F)
M^XE,)#")\0-$)#`/K-D;B4PD,(GQP>$%B4PD0(M,)#`+3"1``<B)1"0PBT0D
M.(M4)#R+3"0XBUPD*,=$)#0`````#ZS0`HGZP>$>B<6+1"1("<V+3"0H`X0D
M\`$``,=$)#P`````QT0D/`````"+?"0\!=R\&X\)Z2'K(?$)V8M<)#2)3"0X
MBTPD,`-$)#B);"1`QT0D1``````/K-D;B4PD.(M,)##'1"1,`````,'A!8E,
M)$B+3"0X"TPD2`'(B40D.(GP#ZS0`HM4)#3!YAZ)PXM$)"@)\P.$)/@!``")
MV8E<)$@%W+P;CPGI(TPD,"'KB<X)W@'PBW0D.`^L_AN+?"0XB?'!YP4)^0'(
MBTPD,#'_B<:+1"0PP>$>#ZS0`HG%"<V);"0HBT0D0(M,)$@#A"0``@``BUPD
M2(M4)#P%W+P;CPGI(TPD."'KQT0D-``````)V8G[B4PD,(GQ`T0D,`^LV1N+
M7"0HB4PD,(GQP>$%B4PD0(M,)#`+3"1`QT0D-`````#'1"0L``````'(BTPD
M.(E$)#"+1"0XQT0D1`````#'1"0\`````,'A'@^LT`*)^HG%BT0D2`G-BTPD
M*`.$)`@"``");"1`!=R\&X\)Z2'K(?$)V8M<)#2)3"0XBTPD,`-$)#@/K-D;
MB4PD.(M,)##'1"0\`````(M\)#S'1"1,`````,=$)"P`````P>$%B4PD2(M,
M)#@+3"1(`<B)1"0XB?`/K-`"BU0D-,'F'HG#BT0D*`GS`X0D$`(``(G9B5PD
M2,=$)#0`````!=R\&X\)Z2-,)#`AZXG."=Z+7"1(`?"+="0X#ZS^&XM\)#B)
M\<'G!0GY`<B+3"0P,?^)QHM$)##!X1X/K-`"B<6+1"1`"<V+3"1(`X0D&`(`
M`(EL)"@%W+P;CPGI(TPD."'K"=F)^XE,)#")\0-$)#`/K-D;B4PD,(GQP>$%
MB4PD0(M,)#`+3"1``<B)1"0PBT0D.(M4)#R+3"0XBUPD*,=$)#0`````#ZS0
M`HGZP>$>B<6+1"1("<V+3"0H`X0D(`(``,=$)#P`````QT0D/`````"+?"0\
M!=R\&X\)Z2'K(?$)V8M<)#2)3"0XBTPD,`-$)#B);"1`QT0D1``````/K-D;
MB4PD.(M,)##'1"1,`````,'A!8E,)$B+3"0X"TPD2`'(B40D.(GP#ZS0`HM4
M)#3!YAZ)PXM$)"@)\P.$)"@"``")V8E<)$@%W+P;CPGI(TPD,"'KB<X)W@'P
MBW0D.`^L_AN+?"0XB?'!YP4)^0'(BTPD,#'_B<:+1"0PP>$>#ZS0`HG%"<V)
M;"0HBT0D0(M,)$@#A"0P`@``BUPD2(M4)#P%W+P;CPGI(TPD."'KQT0D-```
M```)V8G[B4PD,(GQ`T0D,`^LV1N+7"0HB4PD,(GQP>$%B4PD0(M,)#`+3"1`
MQT0D-`````#'1"0L``````'(BTPD.(E$)#"+1"0XQT0D/`````#'1"1$````
M`,'A'@^LT`*)^HG%BT0D2`G-BTPD*`.$)#@"``");"0X!=R\&X\)Z2'K(?$)
MV8M<)#2)3"1`BTPD,`-$)$`/K-D;B4PD0(M,)##'1"1$`````(M\)$3'1"1,
M`````,=$)%P`````P>$%B4PD2(M,)$`+3"1(QT0D+``````!R(M,)#")1"1`
MB?`/K-`"BU0D-,'F'HG#BT0D*`GS`X0D0`(``(G>B5PD2`76P6+*,>XQ\8MT
M)$`!R`^L_AN+?"1`B?'!YP4)^0'(BTPD,#'_B<:+1"0PB?O!X1X/K-`"BU0D
M1(G%BT0D.`G-BTPD0`.$)$@"``");"18!=;!8LHS;"1(,>D!R(GQ#ZS9&XE,
M)"B)\<'A!8E,)#"+3"0H"TPD,`'(BTPD0(E$)"B+1"1`P>$>#ZS0`HGZB<4)
MS8EL)$"+1"1(`X0D4`(``(M<)"S'1"0T`````(M\)#0%UL%BRC-L)%C'1"1$
M`````,=$)#P`````B>DQ\0'(BTPD*,=$)$P`````#ZS9&XE,)#"+3"0HP>$%
MB4PD.(M,)#`+3"0X`<B+3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$)%@)\XMT
M)$`#A"18`@``B5PD.`76P6+*,=XQ\8MT)#`!R`^L_AN+?"0PB?'!YP4)^0'(
MBTPD*#'_B<:+1"0HB?O!X1X/K-`"B<6+1"1`"<V+3"0P`X0D8`(``(EL)$@%
MUL%BRC-L)#@QZ0'(B?$/K-D;B4PD*(GQBU0D-,'A!8E,)$"+3"0H"TPD0,=$
M)"P`````BUPD+,=$)#0``````<B+3"0PB40D*(M$)##'1"1$`````,=$)#P`
M````P>$>#ZS0`HGZBWPD-(G%BT0D.`G-`X0D:`(``(EL)$`%UL%BRC-L)$B)
MZ3'Q`<B+3"0H#ZS9&XE,)#"+3"0HP>$%B4PD.(M,)#`+3"0X`<B+3"0HB40D
M,(GP#ZS0`HM4)"S!YAZ)PXM$)$@)\XMT)$`#A"1P`@``B5PD.`76P6+*,=XQ
M\8MT)#`!R`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HB?O!X1X/K-`"
MB<4)S8EL)$B+1"1``X0D>`(``(M,)#"+5"0T!=;!8LHS;"0XQT0D+`````#'
M1"0T`````#'I`<B)\0^LV1N+7"0LB4PD*(GQP>$%B4PD0(M,)"@+3"1`QT0D
M3`````#'1"1$``````'(BTPD,(E$)"B+1"0PQT0D/`````#!X1X/K-`"B?J+
M?"0TB<6+1"0X"<T#A"2``@``B6PD0`76P6+*,VPD2(GI,?$!R(M,)"@/K-D;
MB4PD,(M,)"C!X06)3"0XBTPD,`M,)#@!R(M,)"B)1"0PB?`/K-`"BU0D+,'F
M'HG#BT0D2`GSBW0D0`.$)(@"``")7"0X!=;!8LHQWC'QBW0D,`'(#ZS^&XM\
M)#")\<'G!0GY`<B+3"0H,?^)QHM$)"B)^\'A'@^LT`*)Q0G-B6PD2(M$)$`#
MA"20`@``BTPD,(M4)#0%UL%BRC-L)#C'1"0L`````,=$)#0`````,>D!R(GQ
M#ZS9&XM<)"R)3"0HB?'!X06)3"1`BTPD*`M,)$#'1"1,`````,=$)$0`````
M`<B+3"0PB40D*(M$)##'1"0\`````,'A'@^LT`*)^HM\)#2)Q8M$)#@)S0.$
M))@"``");"1`!=;!8LHS;"1(B>DQ\0'(BTPD*`^LV1N)3"0PBTPD*,'A!8E,
M)#B+3"0P"TPD.`'(BTPD*(E$)#")\`^LT`*+5"0LP>8>B<.+1"1("?.+="1`
M`X0DH`(``(E<)#@%UL%BRC'>,?&+="0P`<@/K/X;BWPD,(GQP><%"?D!R(M,
M)"@Q_XG&BT0D*(G[P>$>#ZS0`HG%"<V);"1(BT0D0`.$)*@"``"+3"0PBU0D
M-`76P6+*,VPD.,=$)"P`````QT0D-``````QZ0'(B?$/K-D;BUPD+(E,)"B)
M\<'A!8E,)$"+3"0H"TPD0,=$)$P`````QT0D1``````!R(M,)#")1"0HBT0D
M,,=$)#P`````P>$>#ZS0`HGZBWPD-(G%BT0D.`G-`X0DL`(``(EL)$`%UL%B
MRC-L)$B)Z3'Q`<B+3"0H#ZS9&XE,)#"+3"0HP>$%B4PD.(M,)#`+3"0X`<B+
M3"0HB40D,(GP#ZS0`HM4)"S!YAZ)PXM$)$@)\XMT)$`#A"2X`@``B5PD.`76
MP6+*,=XQ\8MT)#`!R`^L_AN+?"0PB?'!YP4)^0'(BTPD*#'_B<:+1"0HB?O!
MX1X/K-`"B<4)S8EL)$B+1"1``X0DP`(``(M,)#"+5"0T!=;!8LHS;"0XQT0D
M+`````#'1"1,`````#'I`<B)\0^LV1N+7"0LB4PD*(GQP>$%B4PD0(M,)"@+
M3"1`QT0D-`````#'1"1$``````'(BTPD,(E$)"B+1"0PP>$>#ZS0`HGZB<6+
M1"0X"<T#A"3(`@``B6PD,`76P6+*,VPD2(GI,?$!R(M,)"@/K-D;B4PD0(M,
M)"C!X06)3"0XBTPD0`M,)#@!R#';B<&)\`^LT`*)W\'F'HG%BT0D2`GUBW0D
M*`.$)-`"``");"1`!=;!8LHS;"0P,>X!\(G.#ZS^&XG/B70D.,'G!8MT)#B)
M?"1(BU0D+`MT)$C'1"0L`````,=$)#P``````?`Q_XG&BT0D*`^LT`*)VHE$
M)$B+1"0HP>`>"T0D2(E$)#B)R`^LT`+!Z@*)1"1(B<B)5"1,B=J+7"0X#Z3"
M'L'@'HE$)%B+1"0P`X0DV`(``(E4)%P%UL%BRC-<)$`QRXGQB5PD*(G[`T0D
M*`^LV1O!ZQN)3"0HB?&)7"0LB?L/I,L%P>$%B4PD,(M,)"@+3"0PB5PD-`'(
MB<&+1"14`TPD((D(QT`$`````(M$)!B+3"14`?")00B+1"1("T0D6`-$)!#'
M00P`````QT$4`````(E!$(M$)#@#1"0(QT$<`````,=!)`````")01B+1"1`
M`P0DB4$@@<3D`@``6UY?7<.-M"8`````C;PG`````%575E.)PX/L+(7`B50D
M''1*H0!4!0B%P(E$)!AT/0^V`SP]=4,Q[8M$)!B+,#'`A?9T*HM\)!B0B6PD
M"(E<)`2)-"3HF-;__X7`=0:`/"X]=#:#QP2+-X7V==TQP(/$+%M>7UW#C78`
MA,!TN8G=@\4!#[9%`#P]=`2$P'7Q*=WKIHVT)@````"+1"0<*WPD&,'_`HDX
M@\0LC40N`5M>7UW#ZPV0D)"0D)"0D)"0D)"0@^P<C50D#.A$____@\0<PU.)
MPX/L&(U4)`R)V.@O____A<!T-HUV`(L5`%0%"(M$)`R-!(*+4`2%THD0=-AF
MD(/`!(M0!(72B1!U](U4)`R)V.CY_O__A<!US8/$&%O#5E.#[!2A"%0%"(D$
M).CNU?__BX!X`0``BW`$H0A4!0B)!"3HV-7__P^VF)`"``"A"%0%"(/C?XD$
M).C!U?__BT`$#[=`$,'@!PG89HE&`J$(5`4(B00DZ*35__^+@'@!``"+6`2A
M"%0%"(D$).B.U?__QT0D"`````#'1"0$1-\$"(D$).@FUO__B4,<H0A4!0B)
M!"3H9M7__XN`>`$``(M8!*$(5`4(B00DZ%#5__^+@)`#``")0R"A"%0%"(D$
M).@ZU?__BX!X`0``BU@$H0A4!0B)!"3H)-7__S'2BXBP!0``A<ET%J$(5`4(
MB00DZ`O5__^+@+`%``"+4'"A"%0%"(E3)(D$).CRU/__BX!X`0``BT`$QT`H
M`````*$(5`4(B00DZ-74__^+@'@!``"+0`3'0!@`````H0A4!0B)!"3HN-3_
M_XN`>`$``(M8!*$(5`4(B00DZ*+4__^+@(`!``")0RR#Q!1;7L.-=@"![)P`
M``"%P(F\))0```")QXF<)(P```")M"20````B:PDF````'0%@#@`=2.+G"2,
M````B[0DD````(N\))0```"+K"28````@<2<````PXD$).BHU/__A<")QG3/
M9I")-"3HJ-/__X7`B<,/A)8```"`>P@N#X2D````B3PD@\,(Z&G2__^)'"2)
MQ>A?TO__C40%`HD$).@CUO__B5PD#(E\)`C'1"0$@-T$"(G%B00DZ$G3__^-
M1"0<B40D"(EL)`3'!"0#````Z-'3__^#^/]T$0^W1"0H)0#P```]`$```'1C
MB2PDZ'/5__^)+"3HV]3__XDT).@3T___A<")PP^%:____Y")-"3HP-/__XD\
M).@8U?__Z1#___^-=@"`>PD`#X0V____@'L)+F:0#X5&____@'L*``^$(/__
M_^DW____C78`B>CHL?[__Y#KFXVT)@````"-O"<`````5HG&4S';@^P4H0A4
M!0B)!"3H&M/__XET)`3'!"0#````@\!<B40D".@CT___A<!T#X/$%(G86U[#
MC;0F`````*$(5`4(B00DZ./2__\/MT!H)0#P```]`$```'0=H0A4!0B)!"3H
MQM+__P^W0&@E`/```#T`H```=;>)-"0QV\=$)`0"````Z+31__^%P`^4PX/$
M%(G86U[#C;0F`````%575HG&4S'`@^P\B=.`.CT/E,`!PXD<).C3T/__C50D
M+(E$)!R)\.A4^___A<")QP^$Z@```(D$).BRT/__,=(Y1"0<#X:V````BTPD
M+,'A`@^V!CP]#X1T`0``A,`/A&P!``")\.L$A-)T"X/``0^V$(#Z/77Q*?"+
M5"0<BST`5`4(C400`@'/B00DZ"_4__^%P(D'#X0\`0``BU0D+*$`5`4(BP20
M#[86A-*($'0D@/H]=!^#Q@'K"XVV`````(#Z/70/#[86@\`!@\8!A-*($'7L
MQ@`],=*-M"8`````#[8,$XA,$`&#P@&$R77Q,<"#Q#Q;7E]=PXVT)@`````/
MM@03B`07@\(!A,!TX0^V!!.(!!>#P@&$P'7DZ]%FD(LM`%0%"#'_N`@```"+
M50"%TG06C70F`(/'`8M,O0"%R77UC02]"````(L50%0%"(72=#2)1"0$B2PD
MZ!#3__^%P(G"HP!4!0AT;(T,O0````#'1+H$`````(E\)"SISO[__Y"-="8`
MQP5`5`4(`0```(D$).@FT___A<!T.8T,O0````")3"0(B4PD%(EL)`2)!"2)
M1"08Z`/2__^+5"08BTPD%(D5`%0%".NEC78`,<#IHO[__[C_____Z1#____K
M#9"0D)"0D)"0D)"0D)"#[!RA"%0%"(D$).B0T/__QT0D#(;=!`C'1"0(\)0$
M",=$)`20W00(B00DZ&#1__^#Q!S#C;8`````C;\`````@^PLH0A4!0B)!"3H
M4-#__XD$).BH____H0A4!0B)!"3H.]#__\=$)!0`````QT0D$$3?!`C'1"0,
M1-\$",=$)`B`UP0(QT0D!*S=!`B)!"3HB]'__X/$+,.-M"8`````,<##C;8`
M````C;PG`````%575E.![$P$``!EH10```")A"0\!```,<"XP]T$"(N<)&`$
M``"+M"1D!```Z%_Y___'1"0$+P```(D<)(G%Z/W-__^%P'0MB=JXS-T$".@-
M_?__BY0D/`0``&4S%10```")V`^%1P$``('$3`0``%M>7UW#B1PDZ-3-___'
M1"0$V=T$"(DT)(E$)"SHH,[__X7`B<=TL8UT)#R-M@````"`/P!U!;_!W00(
MA>UT%(E\)`2)+"3HUL___X7`#X2<````B3PDZ(;-__^`?`?_+W45C;0F````
M`(/H`8!\!_\OQ@0'`'3RBU0D+(U$$`$]_P,```^/3O___XE<)!#'1"0,V]T$
M"(E\)`C'1"0$^MX$"(DT).A'SO__H0A4!0B)!"3HRL[__XET)`3'!"0#````
M@\!<B40D".C#SO__A<!U':$(5`4(B00DZ*+.__\/MT!H)0#P```]`(```'0C
MQT0D!-G=!`C'!"0`````Z+[-__^%P(G'#X4D____Z<;^___'1"0$`0```(DT
M).AOS?__A<!UR8GRN,S=!`CHO_O__XDT).@'S?__B</IH_[__^B+S?__C70F
M`(V\)P````"+1"0$#[8(A,ET(HU0`>L+@\(!#[9*_X3)=!*`^2]U\(G0@\(!
M#[9*_X3)=>[SPY!3@^P8BUPD((7;="R`.P!T)XD<).A'S/__C40#_SG#<@[K
M09"-="8`@^@!.=AT>8`X+W3TZR=FD,<$)`(```#H[,___X7`=`5FQP`N`(/$
M&%O#C;8`````@#@O=`>#Z`$YPW+T.=AT0(/H`3G#<P6`."]T](G",<`IVHU*
M`H'Y``0``'?(@\(!B5PD!(E4)`C'!"1@5`4(Z#3,__^#Q!BX8%0%"%O#9I"`
M."]T$<=$)"#;W00(@\086^D"S/__QP0D`@```.AFS___B<(QP(72#X1W____
M9L<"+@")T.EK____C;0F`````(V\)P````!75H/L-&6A%````(E$)"PQP*%0
MWP0(B40D"J%4WP0(B40D#J%8WP0(B40D$J%<WP0(B40D%J%@WP0(B40D&J%D
MWP0(B40D'J%HWP0(B40D(J%LWP0(B40D)@^W!7#?!`AFB40D*KC=W00(Z%'V
M__^XYMT$".A']O__N.[=!`CH/?;__[CWW00(Z#/V__^X_MT$".@I]O__N`[>
M!`CH'_;__[C#W00(Z!7V__^X&MX$".@+]O__N"3>!`CH`?;__[@NW@0(Z/?U
M__^XS-T$".CM]?__N#C>!`CHX_7__[A!W@0(Z-GU__^X3-X$".B_]?__A<!T
M#(G"N"3>!`CH?_G__[A=W@0(Z*7U__^%P'0,B<*X;]X$".AE^?__N'K>!`CH
MB_7__X7`="^)PKC#W00(Z$OY__^ZIMX$"+C^W00(Z#SY__^+1"0L93,%%```
M`'5)@\0T7E_#D+B*W@0(Z$[U__^%P'02B<*X&MX$".@.^?__Z\&-="8`C70D
M&[^;W@0(N0H```#SIG6KC50D);@:W@0(Z.CX___KF^C!RO__D(/L#*$@^`0(
M@_C_=`N#Q`S#C;0F`````+@:W@0(Z.[T__^)PC'`A=)T#P^V$H32=`@QP(#Z
M,`^5P*,@^`0(@\0,PXVT)@````"-O"<`````@^P<Z"C,__^)!"3HT,O__X7`
M=`R+`(/$',.-M@`````QP.ORC;8`````C;\`````55=64[NRW@0(@^Q<BWPD
M<(UT)#C'1"0TLMX$",=$)#BHW@0(QT0D/+7>!`C'1"1`J]X$",=$)$2PW@0(
MQT0D2,+>!`C'1"1,`````.L<9I")?"0$B00DZ"3+__^%P'0X@\8$BU[\A=MT
M)8G8Z!_T__^%P(G%=`6`.`!UU(G8@\8$B?KHV/?__XM>_(7;==N#Q%Q;7E]=
MPY")/"3HL,C__XDL)(E$)"SHI,C__XM4)"R-1`("B00DZ&3,__^);"00QT0D
M#-G=!`B)?"0(QT0D!/K>!`B)!"2)1"0LZ(#)__^+5"0LB=CH=??__^EP____
M55=64X'L/($``&6A%````(F$)"R!```QP+C#W00(BYPD4($``,=$)%C9W@0(
MQT0D7,'=!`C'1"1@`````,=$)$!OW@0(QT0D1&C>!`C'1"1(WMX$",=$)$R%
MW@0(QT0D4.;>!`C'1"14`````,=$)&3-W@0(QT0D:.K>!`C'1"1L`````.@6
M\___A<!T"8`X``^%V0,``.A$_O__A<")Q0^$ZP,```^V50"$TG0JB%0D).B9
MR___#[94)"2)Z6:0BS`/OM+V!%8(=0/&`5^#P0$/MA&$TG7HC7PD1+AOW@0(
MZP^0C70F`(/'!(M'_(7`="[HJ?+__X7`B<9TZX`X`'3FZ,GU__^%P'3=B30D
MZ*W'__^%P(G'=5"-M"8`````BW0D6#'_A?9T/X`^`+@!````=#6)Q^L8BW2\
M6(7V#X1<`0``@\<!@#X`#X10`0``B?#H>?7__X7`=-V)-"3H7<?__X7`=-&)
MQXD\).COQO__B2PDB<;HY<;__XVT!@0$``")-"3HILK__XEL)!3'1"00\]X$
M",=$)`S;W00(B7PD",=$)`3XW@0(B40D-(D$).BZQ___BT0D-,=$)`3``0``
MB00DZ.;&__^#^/\/A(4```"A"%0%"(D$).@@R/__QP0D`P```(/`7(E$)`B+
M1"0TB40D!.@ER/__A<`/A*4```"+1"0TB40D#(L#QT0D!+#?!`B)1"0(H2!4
M!0B)!"3H6L;__\=$)#@`````BY0D+($``&4S%10```"+1"0X#X4Z"0``@<0\
M@0``6UY?7<.-M"8`````Z$/&__^+`(/X$0^$:____XE$)!"+1"0TB40D#(L#
MQT0D!'3?!`B)1"0(H2!4!0B)!"3H\<7__\=$)#@`````ZY6-M"8`````,?_I
MPO[__Y"A"%0%"(D$).A+Q___#[=`:"4`\```/0!````/A3K___^A"%0%"(D$
M).@JQ___BWAPZ#+(__\YQP^%'?___Z$(5`4(B00DZ`W'__\/MT!H)?\!```]
MP`$```^%_/[__XDT).@AR?__B40D.+BKW@0(Z(/P__^%P`^$L0$``(D$).B3
MQ?__B40D!(L#B00DZ-7V__^%P(G%#X21`0``B2PDZ!/%__^#^`-^)HUT!?R_
M`=\$"+D%````\Z9U%(/X!`^$$@<``(!\!?LO#X0'!P``Z!/[__^%P'4<QT0D
M!`````")+"3H_\3__X7`B40D/`^%0`$``+JFW@0(N!K>!`CHQ//__S';Z$W(
M___'1"041-\$",=$)`S;W00(QT0D!!_?!`B)1"00BT0D-(E$)`B+1"0XB00D
MZ(W%__^+="0XBWPD-.M!C78`Z*O$__^#.!%U2>@!R/__@\,!QT0D&$3?!`B)
M7"04QT0D#-O=!`B)?"0(QT0D!"W?!`B)1"00B30DZ$+%___'1"0$P`$``(DT
M).ARQ/__@_C_=*V+1"0TB00DZ/'&__^+5"0XN,/=!`CH$_/__XM$)#B)!"3H
MI_K__^G`_?__9I")!"2)1"0DZ)3Z__^+1"0DB00DZ#C$__^)1"0XZ9W]__^^
M`0```+C-W@0(ZPZ-=@"+1+1D@\8!A<!T(>CP[O__A<!T[(`X`'3GB00DZ/_#
M__^%P'3;B<7IVOO__[W2W@0(Z0+\__^+*^EH_O__QT0D#`(```#'1"0$[O__
M_\=$)`C_____B00DZ!/'__^+1"0\C50D<,=$)`@&````B50D!(D$).C'Q?__
M@'PD<`!U"X!\)'%##X32!0``BT0D/,=$)`P`````QT0D!`````#'1"0(````
M`(D$).C!QO__QX0D<(````$C16?'A"1T@````````,>$)'B```")J\WOQX0D
M?(````````#'A"2`@```_MRZF,>$)(2`````````QX0DB(```'94,A#'A"2,
M@````````,>$))"```#PX=+#QX0DE(````````#'A"28@````````,>$))R`
M````````QX0DH(````````#'A"2D@````````,>$).B`````````C70F`(M$
M)#R-?"1PQT0D"`"```")?"0$B00DZ,S$__^%P(G##XZ>`0``BX0DF(```(G?
MB=Z+E"2<@```P?\?B40D*(G8B50D+,'@`P-$)"B#?"0L`'<&.40D*'80@X0D
MH(````&#E"2D@````(F$))B```"+A"3H@```#ZS^'<'O'0&T)*"````1O"2D
M@```C50D<(7`QX0DG(````````"-O"2H@```B50D*'1>ND````")WBG".=-^
M`HG6C;PDJ(````'XC50D<(ET)`B)5"0$B00DZ)+$__^+A"3H@````?"#^$")
MA"3H@```#X41____C50D<"GS`?*-A"1P@```B50D*.@!R/__D(/[/P^.DP``
M`(MT)"B)W9"+!H/M0(D'BT8$B4<$BT8(B4<(BT8,B4<,BT80B4<0BT84B4<4
MBT88B4<8BT8<B4<<BT8@B4<@BT8DB4<DBT8HB4<HBT8LB4<LBT8PB4<PBT8T
MB4<TBT8XB4<XBT8\@\9`B4<\C80D<(```.B`Q___@_T_?XN#ZT")VL'J!HU"
M`<'@!@%$)"C!X@8ITXM4)"B)7"0(B3PDB50D!.BPP___B9PDZ(```.D\_O__
MBT0D/(D$).B(PO__BX0DH(```(N4)*2```"+G"28@```B[0DG(```(E$)"B)
M5"0LB=B)\@^LT`.#X#^-4`&#^CC&A`2H@```@`^/K0(``+HW````*<*-A`2I
M@```B50D",=$)`0`````B00DZ+/`__^+5"0LBT0D*(B<).>````/K-`8BU0D
M+(B$)."```"+1"0H#ZS0$(M4)"R(A"3A@```BT0D*`^LT`B)\HB$).*````/
MMD0D*(B$)..```")V`^LT!B)\HB$).2```")V`^LT!")\HB$).6```")V#';
M#ZS0"(B$).:```"-A"1P@```Z$S&__^+M"1P@```B[PD=(```(GPB?H/K-`8
MB?J)P8B$)!B!``")\`^LT!")^HN\)'R```"(A"09@0``B?`/K-`(B?*+M"1X
M@```B(0D&H$``(B4)!N!``")^HGP#ZS0&(GZB(0D'($``(GP#ZS0$(GZB[PD
MA(```(B$)!V!``")\`^LT`B(A"0>@0``B?"+M"2`@```B?J(A"0?@0``B?`/
MK-`8B?J(A"0@@0``B?`/K-`0B?J+O"2,@```B(0D(8$``(GP#ZS0"(GRB[0D
MB(```(B$)"*!``"(E"0C@0``B?J)\`^LT!B)^HB$)"2!``")\`^LT!")^HN\
M))2```"(A"0E@0``B?`/K-`(B(0D)H$``(GPB[0DD(```(GZB(0D)X$``(GP
M#ZS0&(GZB(0D*($``(GP#ZS0$(GZB(0D*8$``(GP#ZS0"(GRB(0D*H$``(VT
M).^```")R(B4)"N!``#K"XUV``^VA!P8@0``#[;`B40D"(T$7H/#`<=$)`0:
MWP0(B00DZ#.___^#^Q1UUL:$)!>!````QT0D%$3?!`B)="00BT0D-,=$)`S;
MW00(QT0D!`O?!`B)1"0(BT0D.(D$).CVOO__Z<3Y__^+6P2%VP^$[OC__XD<
M).C.O?__@_@##X;=^/__C70#_+\&WP0(N04```#SI@^%Q_C__XG=Z<#X__^Z
M/P```"G"C80$J8```(E4)`C'1"0$`````(D$).@&OO__C80D<(```.@:Q/__
MC90DJ(```+D.````,<")U_.KZ3#]__^`?"1R00^%(_K__X!\)'-##X48^O__
M@'PD=$@/A0WZ__^`?"1U10^%`OK__XM$)#S'1"0,`@```,=$)`3&____QT0D
M"/____^)!"3HP\#__XM$)#R-5"1PB50D!,=$)`@I````B00DZ'>___^-5"1P
MQT0D%$3?!`B)5"00Z=C^__]FD.C+O?__C70F`(V\)P````!55U93@^P<H0A4
M!0B)!"3H7+[__\:`D0(```&X_MT$".CKY___A<!T"8`X,0^$G@(``.@I\?__
MH0A4!0B)!"3H++[__\=$)`P+````QT0D"`$```#'1"0$/M\$"(D$).@\OO__
MA<`/A,0```"+0`PQ]HMH&*%D6`4(@_@!#XZC````NP$```#K,8VT)@````"+
M1PR)1"0$H6!8!0B+!)B)!"3H:;[__X7`=76A9%@%"(/#`8/&`3G8?FNA"%0%
M"(D$).BIO?__QT0D#`````")="0(B6PD!(D$).A!O___A<!T/8LX]D<)!'6E
MH0A4!0B)!"3H>+W__\=$)`P"````QT0D"`````")?"0$B00DZ/R\___I>O__
M_XVT)@````"A9%@%"(U0_SGR#X1``0``H0A4!0B)!"3H,[W__\=$)`P$````
MQT0D"`$```#'1"0$0]\$"(D$).A#O?__A<")PW0UBT`,BS"A"%0%"(D$).C[
MO/__QT0D"$7?!`B)="0$B00DZ'>\__^+0PR+&/9#"D`/A1@!``"A"%0%"(D$
M).C+O/__QT0D#`0```#'1"0(`0```,=$)`1*W@0(B00DZ-N\__^%P(G#=#:X
MS-T$".@[YO__A<")Q@^$>0$``(M##(LXH0A4!0B)!"3H?[S__XET)`B)?"0$
MB00DZ/^[__^A"%0%"(D$).ABO/__QH"1`@```*$(5`4(B00DZ$Z\___'@`@$
M````````N,/=!`CHVN7__X7`HVA8!0@/A*4```#'1"0$P`$``(D$).C-NO__
M@_@1=`Z%P'0*@_C_D`^%B`$``(/$'%M>7UW#9I"#^`$/CK?^__^[`0```&:0
MH0A4!0B#PP&)!"3HX+O__XEL)`2)!"3HQ+K__SD=9%@%"'_<Z8?^__^-M"8`
M````H0A4!0B)!"3HL[O__XE<)`2)!"3H][S__^G*_O__9I"`>`$`#X1=_?__
MC;8`````Z4W]__^-=@"A8%@%"(D$).A[\?__A<"C:%@%"`^$X````(M##(L]
M8%@%"(LP]D8)!'1SBT8,B7PD!(D$).C>O/__B<:+0PR+&/9#"00/A($```"+
M0PR)1"0(H6!8!0B)="0,BP#'!"0HX`0(B40D!.CKN___C78`H6!8!0B+.(M#
M#(LPH0A4!0B)!"3H_[K__XE\)`B)="0$B00DZ'^Z___I>_[__Z$(5`4(B00D
MZ-VZ___'1"0,`@```,=$)`@`````B70D!(D$).AANO__Z6+___^A"%0%"(D$
M).BONO__QT0D#`(```#'1"0(`````(E<)`2)!"3H,[K__^E4____QP0D!.`$
M".A2N___B40D#*%H6`4(B40D"*%@6`4(BP#'!"10X`0(B40D!.@NN___C;0F
M`````(V\)P````!64X/L%(MT)"")-"3H/^S__P^V$(G#A-)T(XU``>L,D(/`
M`0^V4/^$TG02@/HO=?")PX/``0^V4/^$TG7NZ)[N__^%P'0@A?9T'(`^`(UV
M`'04QT0D!//>!`B)'"3H?KK__SG8=`:#Q!1;7L.#Q!2)\%M>Z4CE__^0C;0F
M`````(/L'*$(5`4(B00DZ,"Y___'1"0$_____XD$).APN?__H0A4!0B)!"3H
MH[G__\=$)`@`````QT0D!/"_!`B)!"3HJ[O__X/$',.0D)"0D)"058GE4^@X
M````@<-G&@``@^P0BX/\____A<!T`HL`B40D#(M%$(E$)`B+10R)1"0$BT4(
MB00DZ"6Y__^#Q!!;7<.+'"3#D)"0D)"0D)"0D)!5B>5=PXUT)@"-O"<`````
M58GE5U93Z-;___^!PP4:``"#[!SH#[?__XV[[/[__XV#[/[__RG'P?\"A?]T
M)#'VBT40B40D"(M%#(E$)`2+10B)!"3_E+/L_O__@\8!.?YRWH/$'%M>7UW#
MD)"0D)"058GE4X/L!*',]00(@_C_=!.[S/4$"&:0@^L$_]"+`X/X_W7T@\0$
M6UW#D)!5B>53@^P$Z`````!;@<-X&0``Z.R\__]96\G#`P````$``@`E<R\E
M<P!P97)L>'-I+F,`1'EN84QO861E<CHZ8F]O=%]$>6YA3&]A9&5R`$EN=&5R
M;F%L<SHZ4$%2.CI"3T]4`"X`4$%27U1%35``4$%27U!23T=.04U%`#H`+P!0
M15),-4Q)0@!015),3$E"`%!%4DPU3U!4`%!%4DQ)3P!005)?24Y)5$E!3$E:
M140`4$%27U-005=.140`4$%27T-,14%.`%!!4E]$14)51P!005)?0T%#2$4`
M4$%27T%21T,`4$%27T%21U9?,`!005)?1TQ/0D%,7T1%0E5'`%!!4E]'3$]"
M04Q?5$U01$E2`%!!4E]435!$25(`4$%27T=,3T)!3%]414U0`%!!4E]'3$]"
M04Q?0TQ%04X`4$%27T-,14%./0`Q`$Q)0E!!5$@`1%E,1%],24)205)97U!!
M5$@`4TA,24)?4$%42`!54T52`%-94U1%30`O=&UP`%1%35!$25(`5$U0`%53
M15).04U%`'!A<BT`)7,E<R5S)7,`<&%R;``N<&%R`"5S)7-C86-H92TE<R5S
M`"4P,G@`)7,E<W1E;7`M)74E<P`E<R5S=&5M<"TE=2TE=25S`$%21U8`&`!P
M97)L`"UE`"TM`%]?14Y67U!!4E]#3$5!3E]?("`@("`@("`@("`@("`@````
M`"5S.B!C<F5A=&EO;B!O9B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!F86EL
M960@*&5R<FYO/25I*0H``"5S.B!P<FEV871E('-U8F1I<F5C=&]R>2`E<R!I
M<R!U;G-A9F4@*'!L96%S92!R96UO=F4@:70@86YD(')E=')Y('EO=7(@;W!E
M<F%T:6]N*0H``%5N86)L92!T;R!C<F5A=&4@8V%C:&4@9&ER96-T;W)Y````
M`"5S.B!E>&5C=71I;VX@;V8@)7,@9F%I;&5D("AE<G)N;STE:2D*```E<SH@
M8W)E871I;VX@;V8@<')I=F%T92!C86-H92!S=6)D:7)E8W1O<GD@)7,@9F%I
M;&5D("AE<G)N;STE:2D*`````````````(#____/00$;`SO(````&````)"S
M___D````L+?___P$``!0NO__"`$``$#>__](`0``\-[__YP!````W___M`$`
M`%#?___8`0``P.#__P0"```@XO__,`(``,#B__]H`@``L.3__Z@"``#PY/__
MP`(``%#E___8`@``8.7__^P"```@Y___+`,``%#G__]``P``0.C__WP#``#@
MZ?__K`,``##J___,`P``8.K__^@#``!0Z___*`0``.#V__]L!````/O__ZP$
M``"`^___Y`0``!0``````````7I2``%\"`$;#`0$B`$``"`````<````I++_
M_R`$````#@A&#@Q*#PMT!'@`/QH[*C(D(CP```!`````0+G__^(C````00X(
MA0)##@R'`T0.$(8$00X4@P5(#O@%`\PC#A1!#A##00X,QD$.",=!#@3%``!0
M````@````/#<__^A`````$$."(4"00X,AP-!#A"&!$$.%(,%10Y``E<*#A1!
M#A##00X,QD$.",=!#@3%1`MP#A1%PPX00<8.#$''#@A!Q0X$```4````U```
M`$S=__\0`````$,.($P.!``@````[````$3=__]0`````$$."(,"10X@`D@.
M"$$.!,,````H````$`$``'#=__]M`0```$$."(8"00X,@P-##B`#90$.#$$.
M",-!#@3&`"@````\`0``M-[__U(!````1@Z@`4N'`U>%`H8$@P5G"@X$Q<?&
MPT$+````-````&@!``#HW___F0````!!#@B&`D,.#(,#10X@:PH.#$,.",-!
M#@3&2`L"5`X,0\,."$'&#@0\````H`$``%#@___A`0```$$."(4"00X,AP-!
M#A"&!$,.%(,%10Y0`ND*#A1!#A##00X,QD$.",=!#@3%2`L`%````.`!````
MXO__-`````!##B!P#@0`%````/@!```HXO__60````!##C`"50X$$````!`"
M``!PXO__`P`````````\````)`(``&SB__^U`0```$$."(4"00X,AP-!#A"&
M!$$.%(,%1@[@"`)E"@X400X0PT$.#,9!#@C'00X$Q4$+$````&0"``#LX___
M+P`````````X````>`(```CD___B`````$$."(,"0PX@`DP*#@A!#@3#1PL"
M1PH."$;##@1#"U`*#@A!#@3#10L````L````M`(``+SD__^?`0```$$."(<"
M00X,A@-##D`#3P$*#@Q!#@C&00X$QT(+```<````Y`(``"SF__]"`````$,.
M$$T*#@1("VD.!````!@````$`P``7.;__R0`````0PX@5@H.!$<+```\````
M(`,``'#F___P`````$$."(4"00X,AP-!#A"&!$$.%(,%2`YP`H8*#A1!#A##
M00X,QD$.",=!#@3%0@L`0````&`#```@Y___A0L```!!#@B%`D$.#(<#00X0
MA@1!#A2#!48.T(("`T(""@X400X0PT$.#,9!#@C'00X$Q4@+```\````I`,`
M`&SR__\2!````$$."(4"00X,AP-!#A"&!$$.%(,%0PXP`V(""@X400X0PT$.
M#,9!#@C'00X$Q4,+-````.0#``!,]O__>`````!!#@B&`D$.#(,#0PX@`F0*
M#@Q!#@C#00X$QD$+0PX,0PX(PT$.!,84````'`0``)3V__])`````$,.(`)%
M#@0H````-`0``*RR___B`0```$$."(4"0@T%7(,$A@,#9P$*PT'&00P$!,5!
M"P````#_____`````/____\```````````$````!`````0```,`!```!````
MRP$```$```#5`0```0```"0"```!````4@,```P```#XDP0(#0```%S=!`@$
M````B($$"/7^_V^DA`0(!0```.B+!`@&````J(4$"`H```"M!```"P```!``
M```5``````````,```#@]@0(`@````@"```4````$0```!<```#PD00($0``
M`,"1!`@2````,````!,````(````_O__;V"1!`C___]O`@```/#__V^6D`0(
M````````````````````````````````````````````````````````````
M``````````3X!`C@]00(``````````!&E`0(5I0$"&:4!`AVE`0(AI0$"):4
M!`BFE`0(MI0$",:4!`C6E`0(YI0$"/:4!`@&E00(%I4$"":5!`@VE00(1I4$
M"%:5!`AFE00(=I4$"(:5!`B6E00(II4$"+:5!`C&E00(UI4$".:5!`CVE00(
M!I8$"!:6!`@FE@0(-I8$"$:6!`A6E@0(9I8$"':6!`B&E@0(EI8$"*:6!`BV
ME@0(QI8$"-:6!`CFE@0(]I8$"`:7!`@6EP0()I<$"#:7!`A&EP0(5I<$"&:7
M!`AVEP0(AI<$"):7!`BFEP0(MI<$",:7!`C6EP0(YI<$"/:7!`@&F`0(%I@$
M"":8!`@VF`0(1I@$"```````````````````````````````````````````
M`````````````````````/____\`````````````````````````````````
M````(R$O=7-R+V)I;B]P97)L"F5V86P@)V5X96,@+W5S<B]B:6XO<&5R;"`@
M+5,@)#`@)'LQ*R(D0")])PH@("`@:68@,#L@(R!N;W0@<G5N;FEN9R!U;F1E
M<B!S;VUE('-H96QL"@IP86-K86=E(%]?<&%R7W!L.PH*(R`M+2T@5&AI<R!S
M8W)I<'0@;75S="!N;W0@=7-E(&%N>2!M;V1U;&5S(&%T(&-O;7!I;&4@=&EM
M92`M+2T*(R!U<V4@<W1R:6-T.PH*(VQI;F4@,34X"@IM>2`H)'!A<E]T96UP
M+"`D<')O9VYA;64L($!T;7!F:6QE*3L*14Y$('L@:68@*"1%3E9[4$%27T-,
M14%.?2D@>PH@("`@<F5Q=6ER92!&:6QE.CI496UP.PH@("`@<F5Q=6ER92!&
M:6QE.CI"87-E;F%M93L*("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(&UY
M("1T;W!D:7(@/2!&:6QE.CI"87-E;F%M93HZ9&ER;F%M92@D<&%R7W1E;7`I
M.PH@("`@;W5T<RAQ<7M296UO=FEN9R!F:6QE<R!I;B`B)'!A<E]T96UP(GTI
M.PH@("`@1FEL93HZ1FEN9#HZ9FEN9&1E<'1H*'-U8B![("@@+60@*2`_(')M
M9&ER(#H@=6YL:6YK('TL("1P87)?=&5M<"D["B`@("!R;61I<B`D<&%R7W1E
M;7`["B`@("`C($1O;B=T(')E;6]V92!T;W!D:7(@8F5C875S92!T:&ES(&-A
M=7-E<R!A(')A8V4@=VET:"!O=&AE<B!A<'!S"B`@("`C('1H870@87)E('1R
M>6EN9R!T;R!S=&%R="X*"B`@("!I9B`H+60@)'!A<E]T96UP("8F("1>3R!N
M92`G35-7:6XS,B<I('L*("`@("`@("`C(%-O;65T:&EN9R!W96YT('=R;VYG
M('5N;&EN:VEN9R!T:&4@=&5M<&]R87)Y(&1I<F5C=&]R>2X@(%1H:7,*("`@
M("`@("`C('1Y<&EC86QL>2!H87!P96YS(&]N('!L871F;W)M<R!T:&%T(&1I
M<V%L;&]W('5N;&EN:VEN9R!S:&%R960*("`@("`@("`C(&QI8G)A<FEE<R!A
M;F0@97AE8W5T86)L97,@=&AA="!A<F4@:6X@=7-E+B!5;FQI;FL@=VET:"!A
M(&)A8VMG<F]U;F0*("`@("`@("`C('-H96QL(&-O;6UA;F0@<V\@=&AE(&9I
M;&5S(&%R92!N;R!L;VYG97(@:6X@=7-E(&)Y('1H:7,@<')O8V5S<RX*("`@
M("`@("`C($1O;B=T(&1O(&%N>71H:6YG(&]N(%=I;F1O=W,@8F5C875S92!O
M=7(@<&%R96YT('!R;V-E<W,@=VEL;`H@("`@("`@(",@=&%K92!C87)E(&]F
M(&-L96%N:6YG('1H:6YG<R!U<"X*"B`@("`@("`@;7D@)'1M<"`](&YE=R!&
M:6QE.CI496UP*`H@("`@("`@("`@("!414U03$%412`]/B`G=&UP6%A86%@G
M+`H@("`@("`@("`@("!$25(@/3X@1FEL93HZ0F%S96YA;64Z.F1I<FYA;64H
M)'1O<&1I<BDL"B`@("`@("`@("`@(%-51D9)6"`]/B`G+F-M9"<L"B`@("`@
M("`@("`@(%5.3$E.2R`]/B`P+`H@("`@("`@("D["@H@("`@("`@('!R:6YT
M("1T;7`@(B,A+V)I;B]S:`IX/3$[('=H:6QE(%L@7"1X("UL="`Q,"!=.R!D
M;PH@("!R;2`M<F8@)R1P87)?=&5M<"<*("`@:68@6R!<(2`M9"`G)'!A<E]T
M96UP)R!=.R!T:&5N"B`@("`@("!B<F5A:PH@("!F:0H@("!S;&5E<"`Q"B`@
M('@]8&5X<'(@7"1X("L@,6`*9&]N90IR;2`G(B`N("1T;7`M/F9I;&5N86UE
M("X@(B<*(CL*("`@("`@("`@("`@8VAM;V0@,#<P,"PD=&UP+3YF:6QE;F%M
M93L*("`@("`@("!M>2`D8VUD(#T@)'1M<"T^9FEL96YA;64@+B`G(#XO9&5V
M+VYU;&P@,CXF,2`F)SL*("`@("`@("!C;&]S92`D=&UP.PH@("`@("`@('-Y
M<W1E;2@D8VUD*3L*("`@("`@("!O=71S*'%Q*%-P87=N960@8F%C:V=R;W5N
M9"!P<F]C97-S('1O('!E<F9O<FT@8VQE86YU<#H@*0H@("`@("`@("`@("`@
M+B`D=&UP+3YF:6QE;F%M92D["B`@("!]"GT@?0H*0D5'24X@>PH@("`@26YT
M97)N86QS.CI005(Z.D)/3U0H*2!I9B!D969I;F5D("9);G1E<FYA;',Z.E!!
M4CHZ0D]/5#L*"B`@("!E=F%L('L*"E]P87)?:6YI=%]E;G8H*3L*"FEF("AE
M>&ES=',@)$5.5GM005)?05)'5E\P?2!A;F0@)$5.5GM005)?05)'5E\P?2`I
M('L*("`@($!!4D=6(#T@;6%P("1%3E9[(E!!4E]!4D=67R1?(GTL("@Q("XN
M("1%3E9[4$%27T%21T-]("T@,2D["B`@("`D,"`]("1%3E9[4$%27T%21U9?
M,'T["GT*96QS92!["B`@("!F;W(@*&ME>7,@)45.5BD@>PH@("`@("`@(&1E
M;&5T92`D14Y6>R1??2!I9B`O7E!!4E]!4D=67R\["B`@("!]"GT*"FUY("1Q
M=6EE="`]("$D14Y6>U!!4E]$14)51WT["@HC(&9I>"`D<')O9VYA;64@:68@
M:6YV;VME9"!F<F]M(%!!5$@*;7D@)4-O;F9I9R`]("@*("`@('!A=&A?<V5P
M("`@(#T^("@D7D\@/7X@+UY-4U=I;B\@/R`G.R<@.B`G.B<I+`H@("`@7V5X
M92`@("`@("`@/3X@*"1>3R`]?B`O7B@_.DU35VEN?$]3,GQC>6=W:6XI+R`_
M("<N97AE)R`Z("<G*2P*("`@(%]D96QI;2`@("`@(#T^("@D7D\@/7X@+UY-
M4U=I;GQ/4S(O(#\@)UQ<)R`Z("<O)RDL"BD["@I?<V5T7W!R;V=N86UE*"D[
M"E]S971?<&%R7W1E;7`H*3L*"B,@36%G:6,@<W1R:6YG(&-H96-K:6YG(&%N
M9"!E>'1R86-T:6YG(&)U;F1L960@;6]D=6QE<R![>WL*;7D@*"1S=&%R=%]P
M;W,L("1D871A7W!O<RD["GL*("`@(&QO8V%L("1324=[7U]705).7U]](#T@
M<W5B('M].PH*("`@(",@0VAE8VL@9FEL92!T>7!E+"!G970@<W1A<G0@;V8@
M9&%T82!S96-T:6]N('M[>PH@("`@;W!E;B!?1D@L("<\)RP@)'!R;V=N86UE
M(&]R(&QA<W0["B`@("!B:6YM;V1E*%]&2"D["@H@("`@;7D@)&)U9CL*("`@
M('-E96L@7T9(+"`M."P@,CL*("`@(')E860@7T9(+"`D8G5F+"`X.PH@("`@
M;&%S="!U;FQE<W,@)&)U9B!E<2`B7&Y005(N<&U<;B(["@H@("`@<V5E:R!?
M1D@L("TQ,BP@,CL*("`@(')E860@7T9(+"`D8G5F+"`T.PH@("`@<V5E:R!?
M1D@L("TQ,B`M('5N<&%C:R@B3B(L("1B=68I+"`R.PH@("`@<F5A9"!?1D@L
M("1B=68L(#0["@H@("`@)&1A=&%?<&]S(#T@*'1E;&P@7T9(*2`M(#0["B`@
M("`C('U]?0H*("`@(",@17AT<F%C=&EN9R!E86-H(&9I;&4@:6YT;R!M96UO
M<GD@>WM["B`@("!M>2`E<F5Q=6ER95]L:7-T.PH@("`@=VAI;&4@*"1B=68@
M97$@(D9)3$4B*2!["B`@("`@("`@<F5A9"!?1D@L("1B=68L(#0["B`@("`@
M("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B=68I.PH*("`@("`@
M("!M>2`D9G5L;&YA;64@/2`D8G5F.PH@("`@("`@(&]U=',H<7$H56YP86-K
M:6YG(&9I;&4@(B1F=6QL;F%M92(N+BXI*3L*("`@("`@("!M>2`D8W)C(#T@
M*"`D9G5L;&YA;64@/7X@<WQ>*%MA+69<9%U[.'TI+WQ\("D@/R`D,2`Z('5N
M9&5F.PH@("`@("`@(&UY("@D8F%S96YA;64L("1E>'0I(#T@*"1B=68@/7X@
M;7PH/SHN*B\I/R@N*BDH7"XN*BE\*3L*"B`@("`@("`@<F5A9"!?1D@L("1B
M=68L(#0["B`@("`@("`@<F5A9"!?1D@L("1B=68L('5N<&%C:R@B3B(L("1B
M=68I.PH*("`@("`@("!I9B`H9&5F:6YE9"@D97AT*2!A;F0@)&5X="`A?B`O
M7"XH/SIP;7QP;'QI>'QA;"DD+VDI('L*("`@("`@("`@("`@;7D@*"1O=70L
M("1F:6QE;F%M92D@/2!?=&5M<&9I;&4H)&5X="P@)&-R8RD["B`@("`@("`@
M("`@(&EF("@D;W5T*2!["B`@("`@("`@("`@("`@("!B:6YM;V1E*"1O=70I
M.PH@("`@("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@
M("`@("`@8VQO<V4@)&]U=#L*("`@("`@("`@("`@("`@(&-H;6]D(#`W-34L
M("1F:6QE;F%M93L*("`@("`@("`@("`@?0H@("`@("`@("`@("`D4$%2.CI(
M96%V>3HZ1G5L;$-A8VAE>R1F=6QL;F%M97T@/2`D9FEL96YA;64["B`@("`@
M("`@("`@("1005(Z.DAE879Y.CI&=6QL0V%C:&5[)&9I;&5N86UE?2`]("1F
M=6QL;F%M93L*("`@("`@("!]"B`@("`@("`@96QS:68@*"`D9G5L;&YA;64@
M/7X@;7Q>+S]S:&QI8B]\(&%N9"!D969I;F5D("1%3E9[4$%27U1%35!]("D@
M>PH@("`@("`@("`@("`C('-H;W5L9"!B92!M;W9E9"!T;R!?=&5M<&9I;&4H
M*0H@("`@("`@("`@("!M>2`D9FEL96YA;64@/2`B)$5.5GM005)?5$5-4'TO
M)&)A<V5N86UE)&5X="(["B`@("`@("`@("`@(&]U=',H(E-(3$E".B`D9FEL
M96YA;65<;B(I.PH@("`@("`@("`@("!O<&5N(&UY("1O=70L("<^)RP@)&9I
M;&5N86UE(&]R(&1I92`D(3L*("`@("`@("`@("`@8FEN;6]D92@D;W5T*3L*
M("`@("`@("`@("`@<')I;G0@)&]U="`D8G5F.PH@("`@("`@("`@("!C;&]S
M92`D;W5T.PH@("`@("`@('T*("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M)')E<75I<F5?;&ES='LD9G5L;&YA;65](#T*("`@("`@("`@("`@)%!!4CHZ
M2&5A=GDZ.DUO9'5L94-A8VAE>R1F=6QL;F%M97T@/2!["B`@("`@("`@("`@
M("`@("!B=68@/3X@)&)U9BP*("`@("`@("`@("`@("`@(&-R8R`]/B`D8W)C
M+`H@("`@("`@("`@("`@("`@;F%M92`]/B`D9G5L;&YA;64L"B`@("`@("`@
M("`@('T["B`@("`@("`@?0H@("`@("`@(')E860@7T9(+"`D8G5F+"`T.PH@
M("`@?0H@("`@(R!]?7T*"B`@("!L;V-A;"!`24Y#(#T@*'-U8B!["B`@("`@
M("`@;7D@*"1S96QF+"`D;6]D=6QE*2`]($!?.PH*("`@("`@("!R971U<FX@
M:68@<F5F("1M;V1U;&4@;W(@(21M;V1U;&4["@H@("`@("`@(&UY("1F:6QE
M;F%M92`](&1E;&5T92`D<F5Q=6ER95]L:7-T>R1M;V1U;&5]('Q\(&1O('L*
M("`@("`@("`@("`@;7D@)&ME>3L*("`@("`@("`@("`@9F]R96%C:"`H:V5Y
M<R`E<F5Q=6ER95]L:7-T*2!["B`@("`@("`@("`@("`@("!N97AT('5N;&5S
M<R`O7%$D;6]D=6QE7$4D+SL*("`@("`@("`@("`@("`@("1K97D@/2`D7SL@
M;&%S=#L*("`@("`@("`@("`@?0H@("`@("`@("`@("!D96QE=&4@)')E<75I
M<F5?;&ES='LD:V5Y?2!I9B!D969I;F5D*"1K97DI.PH@("`@("`@('T@;W(@
M<F5T=7)N.PH*("`@("`@("`D24Y#>R1M;V1U;&5](#T@(B]L;V%D97(O)&9I
M;&5N86UE+R1M;V1U;&4B.PH*("`@("`@("!I9B`H)$5.5GM005)?0TQ%04Y]
M(&%N9"!D969I;F5D*"9)3SHZ1FEL93HZ;F5W*2D@>PH@("`@("`@("`@("!M
M>2`D9F@@/2!)3SHZ1FEL92T^;F5W7W1M<&9I;&4@;W(@9&EE("0A.PH@("`@
M("`@("`@("!B:6YM;V1E*"1F:"D["B`@("`@("`@("`@('!R:6YT("1F:"`D
M9FEL96YA;64M/GMB=69].PH@("`@("`@("`@("!S965K*"1F:"P@,"P@,"D[
M"B`@("`@("`@("`@(')E='5R;B`D9F@["B`@("`@("`@?0H@("`@("`@(&5L
M<V4@>PH@("`@("`@("`@("!M>2`H)&]U="P@)&YA;64I(#T@7W1E;7!F:6QE
M*"<N<&TG+"`D9FEL96YA;64M/GMC<F-]*3L*("`@("`@("`@("`@:68@*"1O
M=70I('L*("`@("`@("`@("`@("`@(&)I;FUO9&4H)&]U="D["B`@("`@("`@
M("`@("`@("!P<FEN="`D;W5T("1F:6QE;F%M92T^>V)U9GT["B`@("`@("`@
M("`@("`@("!C;&]S92`D;W5T.PH@("`@("`@("`@("!]"B`@("`@("`@("`@
M(&]P96X@;7D@)&9H+"`G/"<L("1N86UE(&]R(&1I92`D(3L*("`@("`@("`@
M("`@8FEN;6]D92@D9F@I.PH@("`@("`@("`@("!R971U<FX@)&9H.PH@("`@
M("`@('T*"B`@("`@("`@9&EE(")";V]T<W1R87!P:6YG(&9A:6QE9#H@8V%N
M;F]T(&9I;F0@)&UO9'5L92%<;B(["B`@("!]+"!`24Y#*3L*"B`@("`C($YO
M=R!L;V%D(&%L;"!B=6YD;&5D(&9I;&5S('M[>PH*("`@(",@:6YI=&EA;&EZ
M92!S:&%R960@;V)J96-T('!R;V-E<W-I;F<*("`@(')E<75I<F4@6%-,;V%D
M97(["B`@("!R97%U:7)E(%!!4CHZ2&5A=GD["B`@("!R97%U:7)E($-A<G`Z
M.DAE879Y.PH@("`@<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!005(Z
M.DAE879Y.CI?:6YI=%]D>6YA;&]A9&5R*"D["@H@("`@(R!N;W<@;&5T)W,@
M=')Y(&=E='1I;F<@:&5L<&5R(&UO9'5L97,@9G)O;2!W:71H:6X*("`@(')E
M<75I<F4@24\Z.D9I;&4["@H@("`@(R!L;V%D(')E<W0@;V8@=&AE(&=R;W5P
M(&EN"B`@("!W:&EL92`H;7D@)&9I;&5N86UE(#T@*'-O<G0@:V5Y<R`E<F5Q
M=6ER95]L:7-T*5LP72D@>PH@("`@("`@("-L;V-A;"`D24Y#>R=#=V0N<&TG
M?2`](%]?1DE,15]?(&EF("1>3R!N92`G35-7:6XS,B<["B`@("`@("`@=6YL
M97-S("@D24Y#>R1F:6QE;F%M97T@;W(@)&9I;&5N86UE(#U^("]"4T1004XO
M*2!["B`@("`@("`@("`@(",@<F5Q=6ER92!M;V1U;&5S+"!D;R!O=&AE<B!E
M>&5C=71A8FQE(&9I;&5S"B`@("`@("`@("`@(&EF("@D9FEL96YA;64@/7X@
M+UPN<&UC/R0O:2D@>PH@("`@("`@("`@("`@("`@<F5Q=6ER92`D9FEL96YA
M;64["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92!["B`@("`@("`@
M("`@("`@("`C(%-K:7`@06-T:79E4W1A=&4G<R!S:71E8W5S=&]M:7IE+G!L
M(&9I;&4Z"B`@("`@("`@("`@("`@("!D;R`D9FEL96YA;64@=6YL97-S("1F
M:6QE;F%M92`]?B`O<VET96-U<W1O;6EZ95PN<&PD+SL*("`@("`@("`@("`@
M?0H@("`@("`@('T*("`@("`@("!D96QE=&4@)')E<75I<F5?;&ES='LD9FEL
M96YA;65].PH@("`@?0H*("`@(",@?7U]"@H@("`@;&%S="!U;FQE<W,@)&)U
M9B!E<2`B4$M<,#`S7#`P-"(["B`@("`D<W1A<G1?<&]S(#T@*'1E;&P@7T9(
M*2`M(#0["GT*(R!]?7T*"B,@07)G=6UE;G0@<')O8V5S<VEN9R![>WL*;7D@
M0'!A<E]A<F=S.PIM>2`H)&]U="P@)&)U;F1L92P@)&QO9V9H+"`D8V%C:&5?
M;F%M92D["@ID96QE=&4@)$5.5GM005)?05!07U)%55-%?3L@(R!S86YI=&EZ
M92`H4D554T4@;6%Y(&)E(&$@<V5C=7)I='D@<')O8FQE;2D*"B1Q=6EE="`]
M(#`@=6YL97-S("1%3E9[4$%27T1%0E5'?3L*(R!$;VXG="!S=V%L;&]W(&%R
M9W5M96YT<R!F;W(@8V]M<&EL960@97AE8W5T86)L97,@=VET:&]U="`M+7!A
M<BUO<'1I;VYS"FEF("@A)'-T87)T7W!O<R!O<B`H)$%21U9;,%T@97$@)RTM
M<&%R+6]P=&EO;G,G("8F('-H:69T*2D@>PH@("`@;7D@)61I<W1?8VUD(#T@
M<7<H"B`@("`@("`@<"`@(&)L:6)?=&]?<&%R"B`@("`@("`@:2`@(&EN<W1A
M;&Q?<&%R"B`@("`@("`@=2`@('5N:6YS=&%L;%]P87(*("`@("`@("!S("`@
M<VEG;E]P87(*("`@("`@("!V("`@=F5R:69Y7W!A<@H@("`@*3L*"B`@("`C
M(&EF('1H92!A<'`@:7,@:6YV;VME9"!A<R`B87!P;F%M92`M+7!A<BUO<'1I
M;VYS("TM<F5U<V4@4%)/1U)!32!`4%)/1U]!4D=6(BP*("`@(",@=7-E('1H
M92!A<'`@=&\@<G5N('1H92!G:79E;B!P97)L(&-O9&4@:6YS=&5A9"!O9B!A
M;GET:&EN9R!F<F]M('1H90H@("`@(R!A<'`@:71S96QF("AB=70@<W1I;&P@
M<V5T('5P('1H92!N;W)M86P@87!P(&5N=FER;VYM96YT(&%N9"!`24Y#*0H@
M("`@:68@*$!!4D=6(&%N9"`D05)'5ELP72!E<2`G+2UR975S92<I('L*("`@
M("`@("!S:&EF="!`05)'5CL*("`@("`@("`D14Y6>U!!4E]!4%!?4D554T5]
M(#T@<VAI9G0@0$%21U8["B`@("!]"B`@("!E;'-E('L@(R!N;W)M86P@<&%R
M;"!B96AA=FEO=7(*"B`@("`@("`@;7D@0&%D9%]T;U]I;F,["B`@("`@("`@
M=VAI;&4@*$!!4D=6*2!["B`@("`@("`@("`@("1!4D=66S!=(#U^("]>+2A;
M04E-3T),8G%P:75S5'9=*2@N*BDO(&]R(&QA<W0["@H@("`@("`@("`@("!I
M9B`H)#$@97$@)TDG*2!["B`@("`@("`@("`@("`@("!P=7-H($!A9&1?=&]?
M:6YC+"`D,CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)TTG*2!["B`@("`@("`@("`@("`@("!E=F%L(")U<V4@)#(B.PH@("`@
M("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D,2!E<2`G02<I('L*("`@
M("`@("`@("`@("`@('5N<VAI9G0@0'!A<E]A<F=S+"`D,CL*("`@("`@("`@
M("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@97$@)T\G*2!["B`@("`@("`@
M("`@("`@("`D;W5T(#T@)#(["B`@("`@("`@("`@('T*("`@("`@("`@("`@
M96QS:68@*"0Q(&5Q("=B)RD@>PH@("`@("`@("`@("`@("`@)&)U;F1L92`]
M("=S:71E)SL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-I9B`H)#$@
M97$@)T(G*2!["B`@("`@("`@("`@("`@("`D8G5N9&QE(#T@)V%L;"<["B`@
M("`@("`@("`@('T*("`@("`@("`@("`@96QS:68@*"0Q(&5Q("=Q)RD@>PH@
M("`@("`@("`@("`@("`@)'%U:65T(#T@,3L*("`@("`@("`@("`@?0H@("`@
M("`@("`@("!E;'-I9B`H)#$@97$@)TPG*2!["B`@("`@("`@("`@("`@("!O
M<&5N("1L;V=F:"P@(CX^(BP@)#(@;W(@9&EE(")86%@Z($-A;FYO="!O<&5N
M(&QO9SH@)"$B.PH@("`@("`@("`@("!]"B`@("`@("`@("`@(&5L<VEF("@D
M,2!E<2`G5"<I('L*("`@("`@("`@("`@("`@("1C86-H95]N86UE(#T@)#([
M"B`@("`@("`@("`@('T*"B`@("`@("`@("`@('-H:69T*$!!4D=6*3L*"B`@
M("`@("`@("`@(&EF("AM>2`D8VUD(#T@)&1I<W1?8VUD>R0Q?2D@>PH@("`@
M("`@("`@("`@("`@9&5L971E("1%3E9[)U!!4E]414U0)WT["B`@("`@("`@
M("`@("`@("!I;FET7VEN8R@I.PH@("`@("`@("`@("`@("`@<F5Q=6ER92!0
M05(Z.D1I<W0["B`@("`@("`@("`@("`@("`F>R)005(Z.D1I<W0Z.B1C;60B
M?2@I('5N;&5S<R!`05)'5CL*("`@("`@("`@("`@("`@("9[(E!!4CHZ1&ES
M=#HZ)&-M9")]*"1?*2!F;W(@0$%21U8["B`@("`@("`@("`@("`@("!E>&ET
M.PH@("`@("`@("`@("!]"B`@("`@("`@?0H*("`@("`@("!U;G-H:69T($!)
M3D,L($!A9&1?=&]?:6YC.PH@("`@?0I]"@HC(%A86"`M+2!A9&0@+2UP87(M
M9&5B=6<@<W5P<&]R="$*"B,@?7U]"@HC($]U='!U="!M;V1E("@M3RD@:&%N
M9&QI;F<@>WM["FEF("@D;W5T*2!["B`@("!["B`@("`@("`@(VQO8V%L("1)
M3D-[)T-W9"YP;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*
M("`@("`@("!R97%U:7)E($E/.CI&:6QE.PH@("`@("`@(')E<75I<F4@07)C
M:&EV93HZ6FEP.PH@("`@?0H*("`@(&UY("1P87(@/2!S:&EF="A`05)'5BD[
M"B`@("!M>2`D>FEP.PH*"B`@("!I9B`H9&5F:6YE9"`D<&%R*2!["B`@("`@
M("`@;W!E;B!M>2`D9F@L("<\)RP@)'!A<B!O<B!D:64@(D-A;FYO="!F:6YD
M("<D<&%R)SH@)"$B.PH@("`@("`@(&)I;FUO9&4H)&9H*3L*("`@("`@("!B
M;&5S<R@D9F@L("=)3SHZ1FEL92<I.PH*("`@("`@("`D>FEP(#T@07)C:&EV
M93HZ6FEP+3YN97<["B`@("`@("`@*"`D>FEP+3YR96%D1G)O;49I;&5(86YD
M;&4H)&9H+"`D<&%R*2`]/2!!<F-H:79E.CI::7`Z.D%:7T]+*"D@*0H@("`@
M("`@("`@("!O<B!D:64@(E)E860@)R1P87(G(&5R<F]R.B`D(2(["B`@("!]
M"@H*("`@(&UY("5E;G8@/2!D;R!["B`@("`@("`@:68@*"1Z:7`@86YD(&UY
M("1M971A(#T@)'II<"T^8V]N=&5N=',H)TU%5$$N>6UL)RDI('L*("`@("`@
M("`@("`@)&UE=&$@/7X@<R\N*EYP87(Z)"\O;7,["B`@("`@("`@("`@("1M
M971A(#U^(',O7EQ3+BHO+VUS.PH@("`@("`@("`@("`D;65T82`]?B`O7B`@
M*%M>.ETK*3H@*"XK*20O;6<["B`@("`@("`@?0H@("`@?3L*"B`@("`C($]P
M96X@:6YP=70@86YD(&]U='!U="!F:6QE<R![>WL*("`@(&QO8V%L("0O(#T@
M7#0["@H@("`@:68@*&1E9FEN960@)'!A<BD@>PH@("`@("`@(&]P96X@4$%2
M+"`G/"<L("1P87(@;W(@9&EE("(D(3H@)'!A<B(["B`@("`@("`@8FEN;6]D
M92A005(I.PH@("`@("`@(&1I92`B)'!A<B!I<R!N;W0@82!005(@9FEL92(@
M=6YL97-S(#Q005(^(&5Q(")02UPP,#-<,#`T(CL*("`@('T*"B`@("!#<F5A
M=&50871H*"1O=70I(#L*("`@(`H@("`@;7D@)&9H(#T@24\Z.D9I;&4M/FYE
M=R@*("`@("`@("`D;W5T+`H@("`@("`@($E/.CI&:6QE.CI/7T-214%4*"D@
M?"!)3SHZ1FEL93HZ3U]74D].3%DH*2!\($E/.CI&:6QE.CI/7U1254Y#*"DL
M"B`@("`@("`@,#<W-RP*("`@("D@;W(@9&EE("0A.PH@("`@8FEN;6]D92@D
M9F@I.PH*("`@("0O(#T@*&1E9FEN960@)&1A=&%?<&]S*2`_(%PD9&%T85]P
M;W,@.B!U;F1E9CL*("`@('-E96L@7T9(+"`P+"`P.PH@("`@;7D@)&QO861E
M<B`]('-C86QA<B`\7T9(/CL*("`@(&EF("@A)$5.5GM005)?5D520D%424U]
M(&%N9"`D;&]A9&5R(#U^("]>*#\Z(R%\7$!R96TI+RD@>PH@("`@("`@(')E
M<75I<F4@4$%2.CI&:6QT97(Z.E!O9%-T<FEP.PH@("`@("`@(%!!4CHZ1FEL
M=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&QO861E<BP@)#`I"B`@("!]
M"B`@("!F;W)E86-H(&UY("1K97D@*'-O<G0@:V5Y<R`E96YV*2!["B`@("`@
M("`@;7D@)'9A;"`]("1E;G9[)&ME>7T@;W(@;F5X=#L*("`@("`@("`D=F%L
M(#T@979A;"`D=F%L(&EF("1V86P@/7X@+UY;)R)=+SL*("`@("`@("!M>2`D
M;6%G:6,@/2`B7U]%3E9?4$%27R(@+B!U8R@D:V5Y*2`N(")?7R(["B`@("`@
M("`@;7D@)'-E="`](")005)?(B`N('5C*"1K97DI("X@(CTD=F%L(CL*("`@
M("`@("`D;&]A9&5R(#U^('-[)&UA9VEC*"`K*7U["B`@("`@("`@("`@("1M
M86=I8R`N("1S970@+B`H)R`G('@@*&QE;F=T:"@D,2D@+2!L96YG=&@H)'-E
M="DI*0H@("`@("`@('UE9SL*("`@('T*("`@("1F:"T^<')I;G0H)&QO861E
M<BD["B`@("`D+R`]('5N9&5F.PH@("`@(R!]?7T*"B`@("`C(%=R:71E(&)U
M;F1L960@;6]D=6QE<R![>WL*("`@(&EF("@D8G5N9&QE*2!["B`@("`@("`@
M<F5Q=6ER92!005(Z.DAE879Y.PH@("`@("`@(%!!4CHZ2&5A=GDZ.E]I;FET
M7V1Y;F%L;V%D97(H*3L*("`@("`@("!I;FET7VEN8R@I.PH*("`@("`@("!R
M97%U:7)E7VUO9'5L97,H*3L*"B`@("`@("`@;7D@0&EN8R`]('-O<G0@>PH@
M("`@("`@("`@("!L96YG=&@H)&(I(#P]/B!L96YG=&@H)&$I"B`@("`@("`@
M?2!G<F5P('L*("`@("`@("`@("`@(2]"4T1004XO"B`@("`@("`@?2!G<F5P
M('L*("`@("`@("`@("`@*"1B=6YD;&4@;F4@)W-I=&4G*2!O<@H@("`@("`@
M("`@("`H)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>V%R8VAL:6)E>'!](&%N9`H@
M("`@("`@("`@("`@)%\@;F4@)$-O;F9I9SHZ0V]N9FEG>W!R:79L:6)E>'!]
M*3L*("`@("`@("!]($!)3D,["@H@("`@("`@(",@1FEL92!E>&ES=',@=&5S
M="!A9&1E9"!T;R!F:7@@4E0@(S0Q-SDP.@H@("`@("`@(",@1G5N;GDL(&YO
M;BUE>&ES=&EN9R!E;G1R>2!I;B!?/"XN+BYA=71O+T-O;7!R97-S+U)A=R]:
M;&EB+V%U=&]S<&QI="YI>"X*("`@("`@("`C(%1H:7,@:7,@82!B86YD+6%I
M9"!F:7@@=VET:"!N;R!D965P97(@9W)A<W`@;V8@=&AE(&ES<W5E+@H@("`@
M("`@(",@4V]M96)O9'D@<&QE87-E(&=O('1H<F]U9V@@=&AE('!A:6X@;V8@
M=6YD97)S=&%N9&EN9R!W:&%T)W,@:&%P<&5N:6YG+`H@("`@("`@(",@22!F
M86EL960N("TM(%-T969F96X*("`@("`@("!M>2`E9FEL97,["B`@("`@("`@
M+UY?/"@N*RDD+R!A;F0@+64@)#$@86YD("1F:6QE<WLD,7TK*R!F;W(@:V5Y
M<R`E.CH["B`@("`@("`@)&9I;&5S>R1??2LK(&9O<B!V86QU97,@)4E.0SL*
M"B`@("`@("`@;7D@)&QI8E]E>'0@/2`D0V]N9FEG.CI#;VYF:6=[;&EB7V5X
M='T["B`@("`@("`@;7D@)7=R:71T96X["@H@("`@("`@(&9O<F5A8V@@*'-O
M<G0@:V5Y<R`E9FEL97,I('L*("`@("`@("`@("`@;7D@*"1N86UE+"`D9FEL
M92D["@H@("`@("`@("`@("!F;W)E86-H(&UY("1D:7(@*$!I;F,I('L*("`@
M("`@("`@("`@("`@(&EF("@D;F%M92`]("1005(Z.DAE879Y.CI&=6QL0V%C
M:&5[)%]]*2!["B`@("`@("`@("`@("`@("`@("`@)&9I;&4@/2`D7SL*("`@
M("`@("`@("`@("`@("`@("!L87-T.PH@("`@("`@("`@("`@("`@?0H@("`@
M("`@("`@("`@("`@96QS:68@*"]>*%Q1)&1I<EQ%7"\H+BI;7D-C72DI7%HO
M:2D@>PH@("`@("`@("`@("`@("`@("`@("@D9FEL92P@)&YA;64I(#T@*"0Q
M+"`D,BD["B`@("`@("`@("`@("`@("`@("`@;&%S=#L*("`@("`@("`@("`@
M("`@('T*("`@("`@("`@("`@("`@(&5L<VEF("AM(5XO;&]A9&5R+UM>+UTK
M+R@N*EM>0V-=*5Q:(2D@>PH@("`@("`@("`@("`@("`@("`@(&EF("AM>2`D
M<F5F(#T@)%!!4CHZ2&5A=GDZ.DUO9'5L94-A8VAE>R0Q?2D@>PH@("`@("`@
M("`@("`@("`@("`@("`@("`H)&9I;&4L("1N86UE*2`]("@D<F5F+"`D,2D[
M"B`@("`@("`@("`@("`@("`@("`@("`@(&QA<W0["B`@("`@("`@("`@("`@
M("`@("`@?0H@("`@("`@("`@("`@("`@("`@(&5L<VEF("@M9B`B)&1I<B\D
M,2(I('L*("`@("`@("`@("`@("`@("`@("`@("`@*"1F:6QE+"`D;F%M92D@
M/2`H(B1D:7(O)#$B+"`D,2D["B`@("`@("`@("`@("`@("`@("`@("`@(&QA
M<W0["B`@("`@("`@("`@("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H@
M("`@("`@("`@("!]"@H@("`@("`@("`@("!N97AT('5N;&5S<R!D969I;F5D
M("1N86UE(&%N9"!N;W0@)'=R:71T96Y[)&YA;65]*RL["B`@("`@("`@("`@
M(&YE>'0@:68@(7)E9B@D9FEL92D@86YD("1F:6QE(#U^("]<+EQ1)&QI8E]E
M>'1<120O.PH@("`@("`@("`@("!O=71S*"!J;VEN("(B+`H@("`@("`@("`@
M("`@("`@<7$H4&%C:VEN9R`B*2P@<F5F("1F:6QE(#\@)&9I;&4M/GMN86UE
M?2`Z("1F:6QE+`H@("`@("`@("`@("`@("`@<7$H(BXN+BD*("`@("`@("`@
M("`@*3L*"B`@("`@("`@("`@(&UY("1C;VYT96YT.PH@("`@("`@("`@("!I
M9B`H<F5F*"1F:6QE*2D@>PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`D
M9FEL92T^>V)U9GT["B`@("`@("`@("`@('T*("`@("`@("`@("`@96QS92![
M"B`@("`@("`@("`@("`@("!O<&5N($9)3$4L("<\)RP@)&9I;&4@;W(@9&EE
M(")#86XG="!O<&5N("1F:6QE.B`D(2(["B`@("`@("`@("`@("`@("!B:6YM
M;V1E*$9)3$4I.PH@("`@("`@("`@("`@("`@)&-O;G1E;G0@/2`\1DE,13X[
M"B`@("`@("`@("`@("`@("!C;&]S92!&24Q%.PH*("`@("`@("`@("`@("`@
M(%!!4CHZ1FEL=&5R.CI0;V13=')I<"T^;F5W+3YA<'!L>2A<)&-O;G1E;G0L
M("1F:6QE*0H@("`@("`@("`@("`@("`@("`@(&EF("$D14Y6>U!!4E]615)"
M051)37T@86YD("1N86UE(#U^("]<+B@_.G!M?&EX?&%L*20O:3L*"B`@("`@
M("`@("`@("`@("!005(Z.D9I;'1E<CHZ4&%T8VA#;VYT96YT+3YN97<M/F%P
M<&QY*%PD8V]N=&5N="P@)&9I;&4L("1N86UE*3L*("`@("`@("`@("`@?0H*
M("`@("`@("`@("`@;W5T<RAQ<2A7<FET=&5N(&%S("(D;F%M92(I*3L*("`@
M("`@("`@("`@)&9H+3YP<FEN="@B1DE,12(I.PH@("`@("`@("`@("`D9F@M
M/G!R:6YT*'!A8VLH)TXG+"!L96YG=&@H)&YA;64I("L@.2DI.PH@("`@("`@
M("`@("`D9F@M/G!R:6YT*'-P<FEN=&8H"B`@("`@("`@("`@("`@("`B)3`X
M>"\E<R(L($%R8VAI=F4Z.EII<#HZ8V]M<'5T94-20S,R*"1C;VYT96YT*2P@
M)&YA;64*("`@("`@("`@("`@*2D["B`@("`@("`@("`@("1F:"T^<')I;G0H
M<&%C:R@G3B<L(&QE;F=T:"@D8V]N=&5N="DI*3L*("`@("`@("`@("`@)&9H
M+3YP<FEN="@D8V]N=&5N="D["B`@("`@("`@?0H@("`@?0H@("`@(R!]?7T*
M"B`@("`C($YO=R!W<FET92!O=70@=&AE(%!!4B!A;F0@;6%G:6,@<W1R:6YG
M<R![>WL*("`@("1Z:7`M/G=R:71E5&]&:6QE2&%N9&QE*"1F:"D@:68@)'II
M<#L*"B`@("`D8V%C:&5?;F%M92`]('-U8G-T<B`D8V%C:&5?;F%M92P@,"P@
M-#`["B`@("!I9B`H(21C86-H95]N86UE(&%N9"!M>2`D;71I;64@/2`H<W1A
M="@D;W5T*2E;.5TI('L*("`@("`@("!M>2`D8W1X(#T@979A;"![(')E<75I
M<F4@1&EG97-T.CI32$$[($1I9V5S=#HZ4TA!+3YN97<H,2D@?0H@("`@("`@
M("`@("!\?"!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z.E-(03$[($1I9V5S=#HZ
M4TA!,2T^;F5W('T*("`@("`@("`@("`@?'P@979A;"![(')E<75I<F4@1&EG
M97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@(R!7;W)K
M87)O=6YD(&9O<B!B=6<@:6X@1&EG97-T.CI32$$@-2XS."!A;F0@-2XS.0H@
M("`@("`@(&UY("1S:&%?=F5R<VEO;B`](&5V86P@>R`D1&EG97-T.CI32$$Z
M.E9%4E-)3TX@?2!\?"`P.PH@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@
M)S4N,S@G(&]R("1S:&%?=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@
M("`@)&-T>"T^861D9FEL92@D;W5T+"`B8B(I(&EF("@D8W1X*3L*("`@("`@
M("!]"B`@("`@("`@96QS92!["B`@("`@("`@("`@(&EF("@D8W1X(&%N9"!O
M<&5N*&UY("1F:"P@(CPD;W5T(BDI('L*("`@("`@("`@("`@("`@(&)I;FUO
M9&4H)&9H*3L*("`@("`@("`@("`@("`@("1C='@M/F%D9&9I;&4H)&9H*3L*
M("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@('T*("`@
M("`@("!]"@H@("`@("`@("1C86-H95]N86UE(#T@)&-T>"`_("1C='@M/FAE
M>&1I9V5S="`Z("1M=&EM93L*("`@('T*("`@("1C86-H95]N86UE("X](")<
M,"(@>"`H-#$@+2!L96YG=&@@)&-A8VAE7VYA;64I.PH@("`@)&-A8VAE7VYA
M;64@+CT@(D-!0TA%(CL*("`@("1F:"T^<')I;G0H)&-A8VAE7VYA;64I.PH@
M("`@)&9H+3YP<FEN="AP86-K*"=.)RP@)&9H+3YT96QL("T@;&5N9W1H*"1L
M;V%D97(I*2D["B`@("`D9F@M/G!R:6YT*")<;E!!4BYP;5QN(BD["B`@("`D
M9F@M/F-L;W-E.PH@("`@8VAM;V0@,#<U-2P@)&]U=#L*("`@(",@?7U]"@H@
M("`@97AI=#L*?0HC('U]?0H*(R!0<F5P87)E("1P<F]G;F%M92!I;G1O(%!!
M4B!F:6QE(&-A8VAE('M[>PI["B`@("!L87-T('5N;&5S<R!D969I;F5D("1S
M=&%R=%]P;W,["@H@("`@7V9I>%]P<F]G;F%M92@I.PH*("`@(",@3F]W(&QO
M860@=&AE(%!!4B!F:6QE(&%N9"!P=70@:70@:6YT;R!005(Z.DQI8D-A8VAE
M('M[>PH@("`@<F5Q=6ER92!005(["B`@("!005(Z.DAE879Y.CI?:6YI=%]D
M>6YA;&]A9&5R*"D["@H*("`@('L*("`@("`@("`C;&]C86P@)$E.0WLG0W=D
M+G!M)WT@/2!?7T9)3$5?7R!I9B`D7D\@;F4@)TU35VEN,S(G.PH@("`@("`@
M(')E<75I<F4@1FEL93HZ1FEN9#L*("`@("`@("!R97%U:7)E($%R8VAI=F4Z
M.EII<#L*("`@('T*("`@(&UY("1Z:7`@/2!!<F-H:79E.CI::7`M/FYE=SL*
M("`@(&UY("1F:"`]($E/.CI&:6QE+3YN97<["B`@("`D9F@M/F9D;W!E;BAF
M:6QE;F\H7T9(*2P@)W(G*2!O<B!D:64@(B0A.B`D0"(["B`@("`D>FEP+3YR
M96%D1G)O;49I;&5(86YD;&4H)&9H+"`D<')O9VYA;64I(#T]($%R8VAI=F4Z
M.EII<#HZ05I?3TLH*2!O<B!D:64@(B0A.B`D0"(["@H@("`@<'5S:"!`4$%2
M.CI,:6)#86-H92P@)'II<#L*("`@("1005(Z.DQI8D-A8VAE>R1P<F]G;F%M
M97T@/2`D>FEP.PH*("`@("1Q=6EE="`]("$D14Y6>U!!4E]$14)51WT["B`@
M("!O=71S*'%Q*%PD14Y6>U!!4E]414U0?2`]("(D14Y6>U!!4E]414U0?2(I
M*3L*"B`@("!I9B`H9&5F:6YE9"`D14Y6>U!!4E]414U0?2D@>R`C('-H;W5L
M9"!B92!S970@870@=&AI<R!P;VEN="$*("`@("`@("!F;W)E86-H(&UY("1M
M96UB97(@*"`D>FEP+3YM96UB97)S("D@>PH@("`@("`@("`@("!N97AT(&EF
M("1M96UB97(M/FES1&ER96-T;W)Y.PH@("`@("`@("`@("!M>2`D;65M8F5R
M7VYA;64@/2`D;65M8F5R+3YF:6QE3F%M93L*("`@("`@("`@("`@;F5X="!U
M;FQE<W,@)&UE;6)E<E]N86UE(#U^(&U["B`@("`@("`@("`@("`@("!>"B`@
M("`@("`@("`@("`@("`O/W-H;&EB+PH@("`@("`@("`@("`@("`@*#\Z)$-O
M;F9I9SHZ0V]N9FEG>W9E<G-I;VY]+RD_"B`@("`@("`@("`@("`@("`H/SHD
M0V]N9FEG.CI#;VYF:6=[87)C:&YA;65]+RD_"B`@("`@("`@("`@("`@("`H
M6UXO72LI"B`@("`@("`@("`@("`@("`D"B`@("`@("`@("`@('UX.PH@("`@
M("`@("`@("!M>2`D97AT<F%C=%]N86UE(#T@)#$["B`@("`@("`@("`@(&UY
M("1D97-T7VYA;64@/2!&:6QE.CI3<&5C+3YC871F:6QE*"1%3E9[4$%27U1%
M35!]+"`D97AT<F%C=%]N86UE*3L*("`@("`@("`@("`@:68@*"UF("1D97-T
M7VYA;64@)B8@+7,@7R`]/2`D;65M8F5R+3YU;F-O;7!R97-S9613:7IE*"DI
M('L*("`@("`@("`@("`@("`@(&]U=',H<7$H4VMI<'!I;F<@(B1M96UB97)?
M;F%M92(@<VEN8V4@:70@86QR96%D>2!E>&ES=',@870@(B1D97-T7VYA;64B
M*2D["B`@("`@("`@("`@('T@96QS92!["B`@("`@("`@("`@("`@("!O=71S
M*'%Q*$5X=')A8W1I;F<@(B1M96UB97)?;F%M92(@=&\@(B1D97-T7VYA;64B
M*2D["B`@("`@("`@("`@("`@("`D;65M8F5R+3YE>'1R86-T5&]&:6QE3F%M
M960H)&1E<W1?;F%M92D["B`@("`@("`@("`@("`@("!C:&UO9"@P-34U+"`D
M9&5S=%]N86UE*2!I9B`D7D\@97$@(FAP=7@B.PH@("`@("`@("`@("!]"B`@
M("`@("`@?0H@("`@?0H@("`@(R!]?7T*?0HC('U]?0H*(R!)9B!T:&5R92=S
M(&YO(&UA:6XN<&P@=&\@<G5N+"!S:&]W('5S86=E('M[>PIU;FQE<W,@*"10
M05(Z.DQI8D-A8VAE>R1P<F]G;F%M97TI('L*("`@(&1I92`\/"`B+B(@=6YL
M97-S($!!4D=6.PI5<V%G93H@)#`@6R`M06QI8BYP87(@72!;("U)9&ER(%T@
M6R`M36UO9'5L92!=(%L@<W)C+G!A<B!=(%L@<')O9W)A;2YP;"!="B`@("`@
M("`D,"!;("U"?"UB(%T@6RU/;W5T9FEL95T@<W)C+G!A<@HN"B`@("`D14Y6
M>U!!4E]04D]'3D%-17T@/2`D<')O9VYA;64@/2`D,"`]('-H:69T*$!!4D=6
M*3L*?0HC('U]?0H*<W5B($-R96%T95!A=&@@>PH@("`@;7D@*"1N86UE*2`]
M($!?.PH@("`@"B`@("!R97%U:7)E($9I;&4Z.D)A<V5N86UE.PH@("`@;7D@
M*"1B87-E;F%M92P@)'!A=&@L("1E>'0I(#T@1FEL93HZ0F%S96YA;64Z.F9I
M;&5P87)S92@D;F%M92P@*"=<+BXJ)RDI.PH@("`@"B`@("!R97%U:7)E($9I
M;&4Z.E!A=&@["B`@("`*("`@($9I;&4Z.E!A=&@Z.FUK<&%T:"@D<&%T:"D@
M=6YL97-S*"UE("1P871H*3L@(R!M:W!A=&@@9&EE<R!W:71H(&5R<F]R"GT*
M"G-U8B!R97%U:7)E7VUO9'5L97,@>PH@("`@(VQO8V%L("1)3D-[)T-W9"YP
M;2=](#T@7U]&24Q%7U\@:68@)%Y/(&YE("=-4U=I;C,R)SL*"B`@("!R97%U
M:7)E(&QI8CL*("`@(')E<75I<F4@1'EN84QO861E<CL*("`@(')E<75I<F4@
M:6YT96=E<CL*("`@(')E<75I<F4@<W1R:6-T.PH@("`@<F5Q=6ER92!W87)N
M:6YG<SL*("`@(')E<75I<F4@=F%R<SL*("`@(')E<75I<F4@0V%R<#L*("`@
M(')E<75I<F4@0V%R<#HZ2&5A=GD["B`@("!R97%U:7)E($5R<FYO.PH@("`@
M<F5Q=6ER92!%>'!O<G1E<CHZ2&5A=GD["B`@("!R97%U:7)E($5X<&]R=&5R
M.PH@("`@<F5Q=6ER92!&8VYT;#L*("`@(')E<75I<F4@1FEL93HZ5&5M<#L*
M("`@(')E<75I<F4@1FEL93HZ4W!E8SL*("`@(')E<75I<F4@6%-,;V%D97([
M"B`@("!R97%U:7)E($-O;F9I9SL*("`@(')E<75I<F4@24\Z.DAA;F1L93L*
M("`@(')E<75I<F4@24\Z.D9I;&4["B`@("!R97%U:7)E($-O;7!R97-S.CI:
M;&EB.PH@("`@<F5Q=6ER92!!<F-H:79E.CI::7`["B`@("!R97%U:7)E(%!!
M4CL*("`@(')E<75I<F4@4$%2.CI(96%V>3L*("`@(')E<75I<F4@4$%2.CI$
M:7-T.PH@("`@<F5Q=6ER92!005(Z.D9I;'1E<CHZ4&]D4W1R:7`["B`@("!R
M97%U:7)E(%!!4CHZ1FEL=&5R.CI0871C:$-O;G1E;G0["B`@("!R97%U:7)E
M(&%T=')I8G5T97,["B`@("!E=F%L('L@<F5Q=6ER92!#=V0@?3L*("`@(&5V
M86P@>R!R97%U:7)E(%=I;C,R('T["B`@("!E=F%L('L@<F5Q=6ER92!38V%L
M87(Z.E5T:6P@?3L*("`@(&5V86P@>R!R97%U:7)E($%R8VAI=F4Z.E5N>FEP
M.CI"=7)S="!].PH@("`@979A;"![(')E<75I<F4@5&EE.CI(87-H.CI.86UE
M9$-A<'1U<F4@?3L*("`@(&5V86P@>R!R97%U:7)E(%!E<FQ)3SL@<F5Q=6ER
M92!097)L24\Z.G-C86QA<B!].PI]"@HC(%1H92!#('9E<G-I;VX@;V8@=&AI
M<R!C;V1E(&%P<&5A<G,@:6X@;7EL9'(O;6MT;7!D:7(N8PHC(%1H:7,@8V]D
M92!A;'-O(&QI=F5S(&EN(%!!4CHZ4V5T=7!496UP(&%S('-E=%]P87)?=&5M
M<%]E;G8A"G-U8B!?<V5T7W!A<E]T96UP('L*("`@(&EF("AD969I;F5D("1%
M3E9[4$%27U1%35!](&%N9"`D14Y6>U!!4E]414U0?2`]?B`O*"XK*2\I('L*
M("`@("`@("`D<&%R7W1E;7`@/2`D,3L*("`@("`@("!R971U<FX["B`@("!]
M"@H@("`@9F]R96%C:"!M>2`D<&%T:"`H"B`@("`@("`@*&UA<"`D14Y6>R1?
M?2P@<7<H(%!!4E]435!$25(@5$U01$E2(%1%35!$25(@5$5-4"!435`@*2DL
M"B`@("`@("`@<7<H($,Z7%Q414U0("]T;7`@+B`I"B`@("`I('L*("`@("`@
M("!N97AT('5N;&5S<R!D969I;F5D("1P871H(&%N9"`M9"`D<&%T:"!A;F0@
M+7<@)'!A=&@["B`@("`@("`@;7D@)'5S97)N86UE.PH@("`@("`@(&UY("1P
M=W5I9#L*("`@("`@("`C(&1O97,@;F]T('=O<FL@979E<GEW:&5R93H*("`@
M("`@("!E=F%L('LH)'!W=6ED*2`](&=E='!W=6ED*"0^*2!I9B!D969I;F5D
M("0^.WT["@H@("`@("`@(&EF("@@9&5F:6YE9"@F5VEN,S(Z.DQO9VEN3F%M
M92D@*2!["B`@("`@("`@("`@("1U<V5R;F%M92`]("97:6XS,CHZ3&]G:6Y.
M86UE.PH@("`@("`@('T*("`@("`@("!E;'-I9B`H9&5F:6YE9"`D<'=U:60I
M('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)'!W=6ED.PH@("`@("`@('T*
M("`@("`@("!E;'-E('L*("`@("`@("`@("`@)'5S97)N86UE(#T@)$5.5GM5
M4T523D%-17T@?'P@)$5.5GM54T52?2!\?"`G4UE35$5-)SL*("`@("`@("!]
M"B`@("`@("`@)'5S97)N86UE(#U^(',O7%<O7R]G.PH*("`@("`@("!M>2`D
M<W1M<&1I<B`]("(D<&%T:"1#;VYF:6=[7V1E;&EM?7!A<BTD=7-E<FYA;64B
M.PH@("`@("`@(&UK9&ER("1S=&UP9&ER+"`P-S4U.PH@("`@("`@(&EF("@A
M)$5.5GM005)?0TQ%04Y](&%N9"!M>2`D;71I;64@/2`H<W1A="@D<')O9VYA
M;64I*5LY72D@>PH@("`@("`@("`@("!O<&5N("AM>2`D9F@L("(\(BX@)'!R
M;V=N86UE*3L*("`@("`@("`@("`@<V5E:R`D9F@L("TQ."P@,CL*("`@("`@
M("`@("`@<WES<F5A9"`D9F@L(&UY("1B=68L(#8["B`@("`@("`@("`@(&EF
M("@D8G5F(&5Q(")<,$-!0TA%(BD@>PH@("`@("`@("`@("`@("`@<V5E:R`D
M9F@L("TU."P@,CL*("`@("`@("`@("`@("`@('-Y<W)E860@)&9H+"`D8G5F
M+"`T,3L*("`@("`@("`@("`@("`@("1B=68@/7X@<R]<,"\O9SL*("`@("`@
M("`@("`@("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB
M("X@)&)U9CL*("`@("`@("`@("`@?0H@("`@("`@("`@("!E;'-E('L*("`@
M("`@("`@("`@("`@(&UY("1C='@@/2!E=F%L('L@<F5Q=6ER92!$:6=E<W0Z
M.E-(03L@1&EG97-T.CI32$$M/FYE=R@Q*2!]"B`@("`@("`@("`@("`@("`@
M("`@?'P@979A;"![(')E<75I<F4@1&EG97-T.CI32$$Q.R!$:6=E<W0Z.E-(
M03$M/FYE=R!]"B`@("`@("`@("`@("`@("`@("`@?'P@979A;"![(')E<75I
M<F4@1&EG97-T.CI-1#4[($1I9V5S=#HZ340U+3YN97<@?3L*"B`@("`@("`@
M("`@("`@("`C(%=O<FMA<F]U;F0@9F]R(&)U9R!I;B!$:6=E<W0Z.E-(02`U
M+C,X(&%N9"`U+C,Y"B`@("`@("`@("`@("`@("!M>2`D<VAA7W9E<G-I;VX@
M/2!E=F%L('L@)$1I9V5S=#HZ4TA!.CI615)324].('T@?'P@,#L*("`@("`@
M("`@("`@("`@(&EF("@D<VAA7W9E<G-I;VX@97$@)S4N,S@G(&]R("1S:&%?
M=F5R<VEO;B!E<2`G-2XS.2<I('L*("`@("`@("`@("`@("`@("`@("`D8W1X
M+3YA9&1F:6QE*"1P<F]G;F%M92P@(F(B*2!I9B`H)&-T>"D["B`@("`@("`@
M("`@("`@("!]"B`@("`@("`@("`@("`@("!E;'-E('L*("`@("`@("`@("`@
M("`@("`@("!I9B`H)&-T>"!A;F0@;W!E;BAM>2`D9F@L("(\)'!R;V=N86UE
M(BDI('L*("`@("`@("`@("`@("`@("`@("`@("`@8FEN;6]D92@D9F@I.PH@
M("`@("`@("`@("`@("`@("`@("`@("`D8W1X+3YA9&1F:6QE*"1F:"D["B`@
M("`@("`@("`@("`@("`@("`@("`@(&-L;W-E*"1F:"D["B`@("`@("`@("`@
M("`@("`@("`@?0H@("`@("`@("`@("`@("`@?0H*("`@("`@("`@("`@("`@
M("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UC86-H92TB("X@*"`D8W1X
M(#\@)&-T>"T^:&5X9&EG97-T(#H@)&UT:6UE("D["B`@("`@("`@("`@('T*
M("`@("`@("`@("`@8VQO<V4H)&9H*3L*("`@("`@("!]"B`@("`@("`@96QS
M92!["B`@("`@("`@("`@("1%3E9[4$%27T-,14%.?2`](#$["B`@("`@("`@
M("`@("1S=&UP9&ER("X]("(D0V]N9FEG>U]D96QI;7UT96UP+20D(CL*("`@
M("`@("!]"@H@("`@("`@("1%3E9[4$%27U1%35!](#T@)'-T;7!D:7(["B`@
M("`@("`@;6MD:7(@)'-T;7!D:7(L(#`W-34["B`@("`@("`@;&%S=#L*("`@
M('T*"B`@("`D<&%R7W1E;7`@/2`D,2!I9B`D14Y6>U!!4E]414U0?2!A;F0@
M)$5.5GM005)?5$5-4'T@/7X@+R@N*RDO.PI]"@IS=6(@7W1E;7!F:6QE('L*
M("`@(&UY("@D97AT+"`D8W)C*2`]($!?.PH@("`@;7D@*"1F:"P@)&9I;&5N
M86UE*3L*"B`@("`D9FEL96YA;64@/2`B)'!A<E]T96UP+R1C<F,D97AT(CL*
M"B`@("!I9B`H)$5.5GM005)?0TQ%04Y]*2!["B`@("`@("`@=6YL:6YK("1F
M:6QE;F%M92!I9B`M92`D9FEL96YA;64["B`@("`@("`@<'5S:"!`=&UP9FEL
M92P@)&9I;&5N86UE.PH@("`@?0H@("`@96QS92!["B`@("`@("`@<F5T=7)N
M("AU;F1E9BP@)&9I;&5N86UE*2!I9B`H+7(@)&9I;&5N86UE*3L*("`@('T*
M"B`@("!O<&5N("1F:"P@)SXG+"`D9FEL96YA;64@;W(@9&EE("0A.PH@("`@
M8FEN;6]D92@D9F@I.PH@("`@<F5T=7)N*"1F:"P@)&9I;&5N86UE*3L*?0H*
M(R!S86UE(&-O9&4@;&EV97,@:6X@4$%2.CI3971U<%!R;V=N86UE.CIS971?
M<')O9VYA;64*<W5B(%]S971?<')O9VYA;64@>PH@("`@:68@*&1E9FEN960@
M)$5.5GM005)?4%)/1TY!345](&%N9"`D14Y6>U!!4E]04D]'3D%-17T@/7X@
M+R@N*RDO*2!["B`@("`@("`@)'!R;V=N86UE(#T@)#$["B`@("!]"@H@("`@
M)'!R;V=N86UE('Q\/2`D,#L*"B`@("!I9B`H)$5.5GM005)?5$5-4'T@86YD
M(&EN9&5X*"1P<F]G;F%M92P@)$5.5GM005)?5$5-4'TI(#X](#`I('L*("`@
M("`@("`D<')O9VYA;64@/2!S=6)S='(H)'!R;V=N86UE+"!R:6YD97@H)'!R
M;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI("L@,2D["B`@("!]"@H@("`@:68@
M*"$D14Y6>U!!4E]04D]'3D%-17T@;W(@:6YD97@H)'!R;V=N86UE+"`D0V]N
M9FEG>U]D96QI;7TI(#X](#`I('L*("`@("`@("!I9B`H;W!E;B!M>2`D9F@L
M("<\)RP@)'!R;V=N86UE*2!["B`@("`@("`@("`@(')E='5R;B!I9B`M<R`D
M9F@["B`@("`@("`@?0H@("`@("`@(&EF("@M<R`B)'!R;V=N86UE)$-O;F9I
M9WM?97AE?2(I('L*("`@("`@("`@("`@)'!R;V=N86UE("X]("1#;VYF:6=[
M7V5X97T["B`@("`@("`@("`@(')E='5R;CL*("`@("`@("!]"B`@("!]"@H@
M("`@9F]R96%C:"!M>2`D9&ER("AS<&QI="`O7%$D0V]N9FEG>W!A=&A?<V5P
M?5Q%+RP@)$5.5GM0051(?2D@>PH@("`@("`@(&YE>'0@:68@97AI<W1S("1%
M3E9[4$%27U1%35!](&%N9"`D9&ER(&5Q("1%3E9[4$%27U1%35!].PH@("`@
M("`@("1D:7(@/7X@<R]<421#;VYF:6=[7V1E;&EM?5Q%)"\O.PH@("`@("`@
M("@H)'!R;V=N86UE(#T@(B1D:7(D0V]N9FEG>U]D96QI;7TD<')O9VYA;64D
M0V]N9FEG>U]E>&5](BDL(&QA<W0I"B`@("`@("`@("`@(&EF("US("(D9&ER
M)$-O;F9I9WM?9&5L:6U])'!R;V=N86UE)$-O;F9I9WM?97AE?2(["B`@("`@
M("`@*"@D<')O9VYA;64@/2`B)&1I<B1#;VYF:6=[7V1E;&EM?21P<F]G;F%M
M92(I+"!L87-T*0H@("`@("`@("`@("!I9B`M<R`B)&1I<B1#;VYF:6=[7V1E
M;&EM?21P<F]G;F%M92(["B`@("!]"GT*"G-U8B!?9FEX7W!R;V=N86UE('L*
M("`@("0P(#T@)'!R;V=N86UE('Q\/2`D14Y6>U!!4E]04D]'3D%-17T["B`@
M("!I9B`H:6YD97@H)'!R;V=N86UE+"`D0V]N9FEG>U]D96QI;7TI(#P@,"D@
M>PH@("`@("`@("1P<F]G;F%M92`]("(N)$-O;F9I9WM?9&5L:6U])'!R;V=N
M86UE(CL*("`@('T*"B`@("`C(%A86"`M(&AA8VL@=&\@;6%K92!05T0@=V]R
M:PH@("`@;7D@)'!W9"`]("AD969I;F5D("9#=V0Z.F=E=&-W9"D@/R!#=V0Z
M.F=E=&-W9"@I"B`@("`@("`@("`@("`@("`Z("@H9&5F:6YE9"`F5VEN,S(Z
M.D=E=$-W9"D@/R!7:6XS,CHZ1V5T0W=D*"D@.B!@<'=D8"D["B`@("!C:&]M
M<"@D<'=D*3L*("`@("1P<F]G;F%M92`]?B!S+UXH/SU<+EPN/UQ1)$-O;F9I
M9WM?9&5L:6U]7$4I+R1P=V0D0V]N9FEG>U]D96QI;7TO.PH*("`@("1%3E9[
M4$%27U!23T=.04U%?2`]("1P<F]G;F%M93L*?0H*<W5B(%]P87)?:6YI=%]E
M;G8@>PH@("`@:68@*"`D14Y6>U!!4E])3DE424%,25I%1'TK*R`]/2`Q("D@
M>PH@("`@("`@(')E='5R;CL*("`@('T@96QS92!["B`@("`@("`@)$5.5GM0
M05)?24Y)5$E!3$E:141](#T@,CL*("`@('T*"B`@("!F;W(@*'%W*"!34$%7
M3D5$(%1%35`@0TQ%04X@1$5"54<@0T%#2$4@4%)/1TY!344@05)'0R!!4D=6
M7S`@*2`I('L*("`@("`@("!D96QE=&4@)$5.5GLG4$%27R<N)%]].PH@("`@
M?0H@("`@9F]R("AQ=R\@5$U01$E2(%1%35`@0TQ%04X@1$5"54<@+RD@>PH@
M("`@("`@("1%3E9[)U!!4E\G+B1??2`]("1%3E9[)U!!4E]'3$]"04Q?)RXD
M7WT@:68@97AI<W1S("1%3E9[)U!!4E]'3$]"04Q?)RXD7WT["B`@("!]"@H@
M("`@;7D@)'!A<E]C;&5A;B`](")?7T5.5E]005)?0TQ%04Y?7R`@("`@("`@
M("`@("`@("(["@H@("`@:68@*"1%3E9[4$%27U1%35!]*2!["B`@("`@("`@
M9&5L971E("1%3E9[4$%27T-,14%.?3L*("`@('T*("`@(&5L<VEF("@A97AI
M<W1S("1%3E9[4$%27T=,3T)!3%]#3$5!3GTI('L*("`@("`@("!M>2`D=F%L
M=64@/2!S=6)S='(H)'!A<E]C;&5A;BP@,3(@*R!L96YG=&@H(D-,14%.(BDI
M.PH@("`@("`@("1%3E9[4$%27T-,14%.?2`]("0Q(&EF("1V86QU92`]?B`O
M7E!!4E]#3$5!3CTH7%,K*2\["B`@("!]"GT*"G-U8B!O=71S('L*("`@(')E
M='5R;B!I9B`D<75I970["B`@("!I9B`H)&QO9V9H*2!["B`@("`@("`@<')I
M;G0@)&QO9V9H(")`7UQN(CL*("`@('T*("`@(&5L<V4@>PH@("`@("`@('!R
M:6YT(")`7UQN(CL*("`@('T*?0H*<W5B(&EN:71?:6YC('L*("`@(')E<75I
M<F4@0V]N9FEG.PH@("`@<'5S:"!`24Y#+"!G<F5P(&1E9FEN960L(&UA<"`D
M0V]N9FEG.CI#;VYF:6=[)%]]+"!Q=R@*("`@("`@("!A<F-H;&EB97AP('!R
M:79L:6)E>'`@<VET96%R8VAE>'`@<VET96QI8F5X<`H@("`@("`@('9E;F1O
M<F%R8VAE>'`@=F5N9&]R;&EB97AP"B`@("`I.PI]"@HC(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C(R,C
M(R,C(R,C(R,C(R,C(R,*(R!4:&4@;6%I;B!P86-K86=E(&9O<B!S8W)I<'0@
M97AE8W5T:6]N"@IP86-K86=E(&UA:6X["@IR97%U:7)E(%!!4CL*=6YS:&EF
M="!`24Y#+"!<)E!!4CHZ9FEN9%]P87(["E!!4BT^:6UP;W)T*$!P87)?87)G
M<RD["@ID:64@<7$H<&%R+G!L.B!#86XG="!O<&5N('!E<FP@<V-R:7!T("(D
M<')O9VYA;64B.B!.;R!S=6-H(&9I;&4@;W(@9&ER96-T;W)Y7&XI"B`@("!U
M;FQE<W,@+64@)'!R;V=N86UE.PH*9&\@)'!R;V=N86UE.PI#3U)%.CIE>&ET
M*"0Q*2!I9B`H)$`@/7XO7E]42U]%6$E47UPH*%QD*RE<*2\I.PID:64@)$`@
M:68@)$`["@I].PH*)#HZ7U]%4E)/4B`]("1`(&EF("1`.PI]"@I#3U)%.CIE
M>&ET*"0Q*2!I9B`H)#HZ7U]%4E)/4B`]?B]>7U1+7T58251?7"@H7&0K*5PI
M+RD["F1I92`D.CI?7T524D]2(&EF("0Z.E]?15)23U(["@HQ.PH*(VQI;F4@
M,3`Q,0H*7U]%3D1?7PH`````1T-#.B`H1&5B:6%N(#0N-BXR+34I(#0N-BXR
M`$=#0SH@*$1E8FEA;B`T+C0N-BTQ,"D@-"XT+C8``"YS:'-T<G1A8@`N:6YT
M97)P`"YN;W1E+D%"22UT86<`+FYO=&4N9VYU+F)U:6QD+6ED`"YG;G4N:&%S
M:``N9'EN<WEM`"YD>6YS='(`+F=N=2YV97)S:6]N`"YG;G4N=F5R<VEO;E]R
M`"YR96PN9'EN`"YR96PN<&QT`"YI;FET`"YT97AT`"YF:6YI`"YR;V1A=&$`
M+F5H7V9R86UE7VAD<@`N96A?9G)A;64`+F-T;W)S`"YD=&]R<P`N:F-R`"YD
M>6YA;6EC`"YG;W0`+F=O="YP;'0`+F1A=&$`+F)S<P`N8V]M;65N=```````
M````````````````````````````````````````````````````"P````$`
M```"````-($$"#0!```-```````````````!`````````!,````'`````@``
M`$2!!`A$`0``(```````````````!``````````A````!P````(```!D@00(
M9`$``"0```````````````0`````````.`````4````"````B($$"(@!```<
M`P``!@`````````$````!````#0```#V__]O`@```*2$!`BD!```!`$```8`
M````````!`````0````^````"P````(```"HA00(J`4``$`&```'`````0``
M``0````0````1@````,````"````Z(L$".@+``"M!``````````````!````
M`````$X```#___]O`@```):0!`B6$```R`````8``````````@````(```!;
M````_O__;P(```!@D00(8!$``&`````'`````@````0`````````:@````D`
M```"````P)$$",`1```P````!@`````````$````"````',````)`````@``
M`/"1!`CP$0``"`(```8````-````!`````@```!\`````0````8```#XDP0(
M^!,``#````````````````0`````````=P````$````&````,)0$"#`4```@
M!``````````````0````!````((````!````!@```%"8!`A0&```#$4`````
M````````$`````````"(`````0````8```!<W00(7%T``!P`````````````
M``0`````````C@````$````"````>-T$"'A=```H`P`````````````(````
M`````)8````!`````@```*#@!`B@8```S```````````````!`````````"D
M`````0````(```!LX00(;&$``&`$``````````````0`````````K@````$`
M```#````S/4$",QE```(```````````````$`````````+4````!`````P``
M`-3U!`C490``"```````````````!`````````"\`````0````,```#<]00(
MW&4```0```````````````0`````````P0````8````#````X/4$".!E``#X
M````!P`````````$````"````,H````!`````P```-CV!`C89@``"```````
M````````!`````0```#/`````0````,```#@]@0(X&8``!`!````````````
M``0````$````V`````$````#`````/@$"`!H``#D6P`````````````@````
M`````-X````(`````P````!4!0CDPP``<`0`````````````(`````````#C
M`````0```#``````````Y,,``#D```````````````$````!`````0````,`
B`````````````!W$``#L```````````````!````````````
